Option Strict Off
Option Explicit On

Imports System
Imports System.Runtime.InteropServices

Namespace InstrumentDriversVB
    
    Public Class rssgs
        Inherits Object
        Implements System.IDisposable
        
        Private _handle As System.Runtime.InteropServices.HandleRef
        
        Private _disposed As Boolean = true
        
        '''<summary>
        '''This function creates an IVI instrument driver session, typically using the C session instrument handle.
        '''</summary>
        '''<param name="Instrument_Handle">
        '''The instrument handle that is used to create an IVI instrument driver session.
        '''</param>
        Public Sub New(ByVal Instrument_Handle As System.IntPtr)
            MyBase.New
            Me._handle = New System.Runtime.InteropServices.HandleRef(Me, Instrument_Handle)
            Me._disposed = false
        End Sub
        
        '''<summary>
        '''This function performs the following initialization actions:
        '''
        '''- Opens a session to the Default Resource Manager resource and a session to the specified device using the interface and address specified in the Resource_Name control.
        '''
        '''- Performs an identification query on the Instrument.
        '''
        '''- Resets the instrument to a known state.
        '''
        '''- Sends initialization commands to the instrument that set any necessary programmatic variables such as Headers Off, Short Command form, and Data Transfer Binary to the state necessary for the operation of the instrument driver.
        '''
        '''- Returns an Instrument Handle which is used to differentiate between different sessions of this instrument driver.
        '''
        '''- Each time this function is invoked a Unique Session is opened.  It is possible to have more than one session open for the same resource.
        '''
        '''</summary>
        '''<param name="Resource_Name">
        '''This control specifies the interface and address of the device that is to be initialized (Instrument Descriptor). The exact grammar to be used in this control is shown in the note below. 
        '''
        '''Default Value:  "GPIB::28"
        '''
        '''Notes:
        '''
        '''(1) Based on the Instrument Descriptor, this operation establishes a communication session with a device.  The grammar for the Instrument Descriptor is shown below.  Optional parameters are shown in square brackets ([]).
        '''
        '''Interface   Grammar
        '''------------------------------------------------------
        '''GPIB        GPIB[board]::primary address[::secondary address]
        '''            [::INSTR]
        '''VXI-11      TCPIP::remote_host::INSTR 
        '''USB         USB::&lt;vendor Id&gt;::&lt;product Id&gt;::&lt;serial number&gt;
        '''            
        '''The GPIB keyword is used for GPIB interface.
        '''The TCPIP keyword is used for VXI-11 interface.
        '''The USB keyword is used for USB interface, where                           
        ''' &lt;vendor Id&gt; is 0x0AAD for Rohde&amp;Schwarz                                    
        ''' &lt;product Id&gt; is 0x0054 for SMB100A                                         
        ''' &lt;serial number&gt; is Serial number (on the rear panel of                     
        ''' the instrument). For example 100001.
        '''
        '''Examples:
        '''(1) GPIB   - "GPIB::28::INSTR"
        '''(2) VXI-11 - "TCPIP::192.168.1.33::INSTR"
        '''(3) USB    - "USB::0xAAD::0x0054::100001::INSTR"
        '''
        '''The default value for optional parameters are shown below.
        '''
        '''Optional Parameter          Default Value
        '''-----------------------------------------
        '''board                       0
        '''secondary address           none - 31
        '''
        '''</param>
        '''<param name="ID_Query">
        '''This control specifies if an ID Query is sent to the instrument during the initialization procedure.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Skip Query
        '''VI_TRUE  (1) - Do Query (Default Value)
        '''
        '''Notes:
        '''   
        '''(1) Under normal circumstances the ID Query ensures that the instrument initialized is the type supported by this driver. However circumstances may arise where it is undesirable to send an ID Query to the instrument.  In those cases; set this control to "Skip Query" and this function will initialize the selected interface, without doing an ID Query.
        '''
        '''</param>
        '''<param name="Reset_Device">
        '''This control specifies if the instrument is to be reset to its power-on settings during the initialization procedure.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Don't Reset
        '''VI_TRUE  (1) - Reset Device (Default Value)
        '''
        '''Notes:
        '''
        '''(1) If you do not want the instrument reset. Set this control to "Don't Reset" while initializing the instrument.
        '''
        '''</param>
        Public Sub New(ByVal Resource_Name As String, ByVal ID_Query As Boolean, ByVal Reset_Device As Boolean)
            MyBase.New
            Dim instrumentHandle As System.IntPtr
            Dim pInvokeResult As Integer = PInvoke.init(Resource_Name, System.Convert.ToUInt16(ID_Query), System.Convert.ToUInt16(Reset_Device), instrumentHandle)
            Me._handle = New System.Runtime.InteropServices.HandleRef(Me, instrumentHandle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Me._disposed = false
        End Sub
        
        '''<summary>
        '''Gets the instrument handle.
        '''</summary>
        '''<value>
        '''The value is the IntPtr that represents the handle to the instrument.
        '''</value>
        Public ReadOnly Property Handle() As System.IntPtr
            Get
                Return Me._handle.Handle
            End Get
        End Property
        
        '''<summary>
        '''This function sets RF frequency and RF level.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]FREQuency[:CW|FIXed]
        '''[:SOURce:]POWer[:LEVel][:IMMediate][:AMPLitude]
        '''</summary>
        '''<param name="Frequency">
        '''Sets the RF frequency of the RF output connector.
        '''
        '''Valid Values:
        '''1.0e+6 to 12.2e+9
        '''
        '''Default Value:
        '''1.0e+6
        '''</param>
        '''<param name="Level">
        '''This control sets the RF signal's power level.
        '''
        '''Valid Values:
        '''-130.0 to 30.0
        '''
        '''Default Value:
        '''-10.0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetFrequencyAndLevel(ByVal Frequency As Double, ByVal Level As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetFrequencyAndLevel(Me._handle, Frequency, Level)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function enables and disables special PCI express features.
        '''
        '''Remote-control command(s):
        '''-
        '''</summary>
        '''<param name="Fast_Enabled">
        '''Activates/deactivates the fast mode.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_FALSE (0)
        '''
        '''</param>
        '''<param name="Asynchronous_Enabled">
        '''Activates/deactivates the asynchronous mode.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_FALSE (0)
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function UseFastSettings(ByVal Fast_Enabled As Boolean, ByVal Asynchronous_Enabled As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.UseFastSettings(Me._handle, System.Convert.ToUInt16(Fast_Enabled), System.Convert.ToUInt16(Asynchronous_Enabled))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''In fast mode this function sends an empty command to  .
        '''
        '''Remote-control command(s):
        '''-
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function FastSync() As Integer
            Dim pInvokeResult As Integer = PInvoke.FastSync(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the state of the signal output.
        '''
        '''Remote-control command(s):
        ''':OUTPut[:STATe]
        '''</summary>
        '''<param name="State">
        '''This control sets the state of the signal output.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value:
        '''VI_FALSE (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetRFState(ByVal State As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetRFState(Me._handle, System.Convert.ToUInt16(State))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the state of the signal output.
        '''
        '''Remote-control command(s):
        ''':OUTPut[:STATe]?
        '''</summary>
        '''<param name="State">
        '''Displays the state of the signal output.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetRFState(ByRef State As Boolean) As Integer
            Dim StateAsUShort As UShort
            Dim pInvokeResult As Integer = PInvoke.GetRFState(Me._handle, StateAsUShort)
            State = System.Convert.ToBoolean(StateAsUShort)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the number of RF paths.
        '''
        '''Remote-control command(s):
        '''[:SOURce]:PATH:COUNt?
        '''</summary>
        '''<param name="Paths">
        '''Displays the number of RF paths.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetRFNumberofPaths(ByRef Paths As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetRFNumberofPaths(Me._handle, Paths)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the mode of the attenuator at the RF output (Attenuator MODe).
        '''
        '''Remote-control command(s):
        '''OUTPut:AMODe AUTO | FIXed
        '''</summary>
        '''<param name="Attenuator_Mode">
        '''This control sets the mode of the attenuator at the RF output (Attenuator MODe).
        '''
        '''Valid Values:
        '''RSSGS_RF_ATT_MODE_AUTO (0) - Auto
        '''RSSGS_RF_ATT_MODE_FIX  (1) - Fixed
        '''
        '''Default Value:
        '''RSSGS_RF_ATT_MODE_AUTO (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetRFAttenuatorMode(ByVal Attenuator_Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetRFAttenuatorMode(Me._handle, Attenuator_Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the mode of the attenuator at the RF output (Attenuator MODe).
        '''
        '''Remote-control command(s):
        '''OUTPut:AMODe?
        '''</summary>
        '''<param name="Attenuator_Mode">
        '''Displays the mode of the attenuator at the RF output (Attenuator MODe).
        '''
        '''Valid Values:
        '''RSSGS_RF_ATT_MODE_AUTO (0) - Auto
        '''RSSGS_RF_ATT_MODE_FIX  (1) - Fixed
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetRFAttenuatorMode(ByRef Attenuator_Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetRFAttenuatorMode(Me._handle, Attenuator_Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the operation mode. NORMal: normal operation. BBBYpass: Base band bypass mode.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]OPMode BBBYpass | NORMal
        '''
        '''</summary>
        '''<param name="Operation_Mode">
        '''This control sets the operation mode. NORMal: normal operation. BBBYpass: Base band bypass mode.
        '''
        '''Valid Values:
        '''RSSGS_OPERATION_MODE_NORMAL (0) - Normal
        '''RSSGS_OPERATION_MODE_BBY    (1) - Baseband Bypass
        '''
        '''Default Value:
        '''RSSGS_OPERATION_MODE_NORMAL (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetOperationMode(ByVal Operation_Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetOperationMode(Me._handle, Operation_Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the operation mode.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]OPMode?
        '''
        '''</summary>
        '''<param name="Operation_Mode">
        '''Displays the operation mode.
        '''
        '''Valid Values:
        '''RSSGS_OPERATION_MODE_NORMAL (0) - Normal
        '''RSSGS_OPERATION_MODE_BBY    (1) - Baseband Bypass
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetOperationMode(ByRef Operation_Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetOperationMode(Me._handle, Operation_Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the path number of baseband paths.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]BB:PATH:COUNt?
        '''</summary>
        '''<param name="Baseband_Paths">
        '''Displays the path number of baseband paths.
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetBasebandPaths(ByRef Baseband_Paths As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetBasebandPaths(Me._handle, Baseband_Paths)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the local oscillator signal.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]LOSCillator:SOURce EXTernal | INTernal
        '''[:SOURce:]CONNector:REFLo:OUTPut REF | LO | OFF
        '''</summary>
        '''<param name="Source">
        '''This control sets the source of the local oscillator signal.
        '''
        '''Valid Values:
        '''RSSGS_SOURCE_INT (0) - Int
        '''RSSGS_SOURCE_EXT (1) - Ext
        '''
        '''Default Value:
        '''RSSGS_LO_SOURCE_INT (0)
        '''</param>
        '''<param name="Output">
        '''This control sets the signal to be connected to the REF output connector.
        '''
        '''Valid Values:
        '''RSSGS_LO_OUTPUT_REF (0) - REF
        '''RSSGS_LO_OUTPUT_LO  (1) - LO
        '''RSSGS_LO_OUTPUT_OFF (2) - OFF
        '''
        '''Default Value:
        '''RSSGS_LO_OUTPUT_REF (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ConfigureFrequencyLocalOscillator(ByVal Source As Integer, ByVal Output As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureFrequencyLocalOscillator(Me._handle, Source, Output)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the RF frequency of the RF output connector.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]FREQuency[:CW|FIXed]
        '''</summary>
        '''<param name="Frequency">
        '''Sets the RF frequency of the RF output connector.
        '''
        '''Valid Values:
        '''1.0e+6 to 12.2e+9
        '''
        '''Default Value:
        '''1.0e+6
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetFrequency(ByVal Frequency As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetFrequency(Me._handle, Frequency)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the RF frequency of the RF output connector.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]FREQuency[:CW|FIXed]?
        '''</summary>
        '''<param name="Frequency">
        '''Displays the RF frequency of the RF output connector.
        '''
        '''Valid Values:
        '''1.0e+6 to 12.2e+9
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetFrequency(ByRef Frequency As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetFrequency(Me._handle, Frequency)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the RF signal's relative phase.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]PHASe
        '''</summary>
        '''<param name="Delta_Phase">
        '''Sets the RF signal's relative phase.
        '''
        '''Valid Values:
        '''-360.0 to 360.0
        '''
        '''Default Value:
        '''0.0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetFrequencyDeltaPhase(ByVal Delta_Phase As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetFrequencyDeltaPhase(Me._handle, Delta_Phase)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the RF signal's relative phase.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]PHASe?
        '''</summary>
        '''<param name="Delta_Phase">
        '''Displays the RF signal's relative phase.
        '''
        '''Valid Values:
        '''-360.0 to 360.0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetFrequencyDeltaPhase(ByRef Delta_Phase As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetFrequencyDeltaPhase(Me._handle, Delta_Phase)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function adopt the phase set with SOURce:PHASe as the current phase.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]PHASe:REFerence
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetFrequencyDeltaPhaseAsCurrent() As Integer
            Dim pInvokeResult As Integer = PInvoke.SetFrequencyDeltaPhaseAsCurrent(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the source of the local oscillator signal.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]LOSCillator:SOURce EXTernal | INTernal
        '''</summary>
        '''<param name="Source">
        '''This control sets the source of the local oscillator signal.
        '''
        '''Valid Values:
        '''RSSGS_SOURCE_INT (0) - Int
        '''RSSGS_SOURCE_EXT (1) - Ext
        '''
        '''Default Value:
        '''RSSGS_LO_SOURCE_INT (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetFrequencyLocalOscillatorSource(ByVal Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetFrequencyLocalOscillatorSource(Me._handle, Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the source of the local oscillator signal.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]LOSCillator:SOURce?
        '''
        '''</summary>
        '''<param name="Source">
        '''Displays the source of the local oscillator signal.
        '''
        '''Valid Values:
        '''RSSGS_SOURCE_INT (0) - Int
        '''RSSGS_SOURCE_EXT (1) - Ext
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetFrequencyLocalOscillatorSource(ByRef Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetFrequencyLocalOscillatorSource(Me._handle, Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the signal to be connected to the REF output connector.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]CONNector:REFLo:OUTPut REF | LO | OFF
        '''</summary>
        '''<param name="Output">
        '''This control sets the signal to be connected to the REF output connector.
        '''
        '''Valid Values:
        '''RSSGS_LO_OUTPUT_REF (0) - REF
        '''RSSGS_LO_OUTPUT_LO  (1) - LO
        '''RSSGS_LO_OUTPUT_OFF (2) - OFF
        '''
        '''Default Value:
        '''RSSGS_LO_OUTPUT_REF (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetFrequencyLocalOscillatorOutput(ByVal Output As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetFrequencyLocalOscillatorOutput(Me._handle, Output)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the signal to be connected to the REF output connector.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]CONNector:REFLo:OUTPut?
        '''
        '''</summary>
        '''<param name="Output">
        '''Displays the signal to be connected to the REF output connector.
        '''
        '''Valid Values:
        '''RSSGS_LO_OUTPUT_REF (0) - REF
        '''RSSGS_LO_OUTPUT_LO  (1) - LO
        '''RSSGS_LO_OUTPUT_OFF (2) - OFF
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetFrequencyLocalOscillatorOutput(ByRef Output As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetFrequencyLocalOscillatorOutput(Me._handle, Output)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures reference oscillator parameters.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]ROSCillator:SOURce EXTernal | INTernal
        '''[:SOURce:]ROSCillator:EXTernal:FREQuency EF10M | EF100M | EF1000M
        '''[:SOURce:]ROSCillator:OUTPut:FREQuency OF10M | OF100M | OF1000M | OFF
        '''[:SOURce:]LOSCillator:SOURce EXTernal | INTernal
        '''[:SOURce:]CONNector:REFLo:OUTPut REF | LO | OFF
        '''</summary>
        '''<param name="Source">
        '''This control sets the reference oscillator signal source.
        '''
        '''Valid Values:
        '''RSSGS_SOURCE_INT (0) - Int
        '''RSSGS_SOURCE_EXT (1) - Ext
        '''
        '''Default Value:
        '''RSSGS_SOURCE_INT (0)
        '''</param>
        '''<param name="Reference_Frequency">
        '''This control sets the reference output frequency.
        '''
        '''Valid Values:
        '''RSSGS_ROSC_REF_FREQ_OF10M   (0) - 10 MHz
        '''RSSGS_ROSC_REF_FREQ_OF100M  (1) - 100 MHz
        '''RSSGS_ROSC_REF_FREQ_OF1000M (2) - 1000 MHz
        '''RSSGS_ROSC_REF_FREQ_OFF     (3) - Off
        '''
        '''Default Value:
        '''RSSGS_ROSC_REF_FREQ_OF10M   (0)
        '''</param>
        '''<param name="External_Reference_Frequency">
        '''This control sets the external reference input frequency.
        '''
        '''Valid Values:
        '''RSSGS_ROSC_EXT_REF_FREQ_EF10M   (0) - 10 MHz
        '''RSSGS_ROSC_EXT_REF_FREQ_EF100M  (1) - 100 MHz
        '''RSSGS_ROSC_EXT_REF_FREQ_EF1000M (2) - 1000 MHz
        '''
        '''Default Value:
        '''RSSGS_ROSC_EXT_REF_FREQ_EF10M   (0)
        '''</param>
        '''<param name="Local_Oscillator_Source">
        '''This control sets the source of the local oscillator signal.
        '''
        '''Valid Values:
        '''RSSGS_SOURCE_INT (0) - Int
        '''RSSGS_SOURCE_EXT (1) - Ext
        '''
        '''Default Value:
        '''RSSGS_LO_SOURCE_INT (0)
        '''</param>
        '''<param name="Local_Oscillator_Output">
        '''This control sets the signal to be connected to the REF output connector.
        '''
        '''Valid Values:
        '''RSSGS_LO_OUTPUT_REF (0) - REF
        '''RSSGS_LO_OUTPUT_LO  (1) - LO
        '''RSSGS_LO_OUTPUT_OFF (2) - OFF
        '''
        '''Default Value:
        '''RSSGS_LO_OUTPUT_REF (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ConfigureReferenceOscillator(ByVal Source As Integer, ByVal Reference_Frequency As Integer, ByVal External_Reference_Frequency As Integer, ByVal Local_Oscillator_Source As Integer, ByVal Local_Oscillator_Output As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureReferenceOscillator(Me._handle, Source, Reference_Frequency, External_Reference_Frequency, Local_Oscillator_Source, Local_Oscillator_Output)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the reference oscillator signal source.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]ROSCillator:SOURce EXTernal | INTernal
        '''</summary>
        '''<param name="Source">
        '''This control sets the reference oscillator signal source.
        '''
        '''Valid Values:
        '''RSSGS_SOURCE_INT (0) - Int
        '''RSSGS_SOURCE_EXT (1) - Ext
        '''
        '''Default Value:
        '''RSSGS_SOURCE_INT (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetROSCSource(ByVal Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetROSCSource(Me._handle, Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the reference oscillator signal source.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]ROSCillator:SOURce?
        '''
        '''</summary>
        '''<param name="Source">
        '''Displays the reference oscillator signal source.
        '''
        '''Valid Values:
        '''RSSGS_SOURCE_INT (0) - Int
        '''RSSGS_SOURCE_EXT (1) - Ext
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetROSCSource(ByRef Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetROSCSource(Me._handle, Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the reference output frequency.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]ROSCillator:OUTPut:FREQuency OF10M | OF100M | OF1000M
        '''</summary>
        '''<param name="Reference_Frequency">
        '''This control sets the reference output frequency.
        '''
        '''Valid Values:
        '''RSSGS_ROSC_REF_FREQ_OF10M   (0) - 10 MHz
        '''RSSGS_ROSC_REF_FREQ_OF100M  (1) - 100 MHz
        '''RSSGS_ROSC_REF_FREQ_OF1000M (2) - 1000 MHz
        '''
        '''Default Value:
        '''RSSGS_ROSC_REF_FREQ_OF10M   (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetROSCReferenceOutputFrequency(ByVal Reference_Frequency As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetROSCReferenceOutputFrequency(Me._handle, Reference_Frequency)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the reference output frequency.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]ROSCillator:OUTPut:FREQuency?
        '''
        '''</summary>
        '''<param name="Reference_Frequency">
        '''Displays the reference output frequency.
        '''
        '''Valid Values:
        '''RSSGS_ROSC_REF_FREQ_OF10M   (0) - 10 MHz
        '''RSSGS_ROSC_REF_FREQ_OF100M  (1) - 100 MHz
        '''RSSGS_ROSC_REF_FREQ_OF1000M (2) - 1000 MHz
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetROSCReferenceOutputFrequency(ByRef Reference_Frequency As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetROSCReferenceOutputFrequency(Me._handle, Reference_Frequency)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the external reference input frequency.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]ROSCillator:EXTernal:FREQuency EF10M | EF100M | EF1000M
        '''</summary>
        '''<param name="External_Reference_Frequency">
        '''This control sets the external reference input frequency.
        '''
        '''Valid Values:
        '''RSSGS_ROSC_EXT_REF_FREQ_EF10M   (0) - 10 MHz
        '''RSSGS_ROSC_EXT_REF_FREQ_EF100M  (1) - 100 MHz
        '''RSSGS_ROSC_EXT_REF_FREQ_EF1000M (2) - 1000 MHz
        '''
        '''Default Value:
        '''RSSGS_ROSC_EXT_REF_FREQ_EF10M   (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetROSCExternalReferenceFrequency(ByVal External_Reference_Frequency As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetROSCExternalReferenceFrequency(Me._handle, External_Reference_Frequency)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the external reference input frequency.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]ROSCillator:EXTernal:FREQuency?
        '''
        '''</summary>
        '''<param name="External_Reference_Frequency">
        '''Displays the external reference input frequency.
        '''
        '''Valid Values:
        '''RSSGS_ROSC_EXT_REF_FREQ_EF10M   (0) - 10 MHz
        '''RSSGS_ROSC_EXT_REF_FREQ_EF100M  (1) - 100 MHz
        '''RSSGS_ROSC_EXT_REF_FREQ_EF1000M (2) - 1000 MHz
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetROSCExternalReferenceFrequency(ByRef External_Reference_Frequency As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetROSCExternalReferenceFrequency(Me._handle, External_Reference_Frequency)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the external synchronization bandwidth.
        '''
        '''Remote-control command(s):
        ''':SOUR:ROSC:EXT:FREQ &lt;ExternalSyncBandwidth&gt;
        '''
        '''</summary>
        '''<param name="Synchronization_Bandwidth">
        '''This control sets the synchronization bandwidth.
        '''
        '''
        '''Valid Values:
        '''RSSGS_ROSC_EXT_SYNC_BWIDTH_WIDE    (0) - 40 Hz
        '''RSSGS_ROSC_EXT_SYNC_BWIDTH_NARROW  (1) - 250 Hz
        '''
        '''Default Value: RSSGS_ROSC_EXT_SYNC_BWIDTH_WIDE (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetROSCExternalSyncBandwidth(ByVal Synchronization_Bandwidth As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetROSCExternalSyncBandwidth(Me._handle, Synchronization_Bandwidth)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the external synchronization bandwidth.
        '''
        '''Remote-control command(s):
        ''':SOUR:ROSC:EXT:FREQ?
        '''
        '''</summary>
        '''<param name="Synchronization_Bandwidth">
        '''Displays the synchronization bandwidth.
        '''
        '''Valid Values:
        '''RSSGS_ROSC_EXT_SYNC_BWIDTH_WIDE    (0) - 40 Hz
        '''RSSGS_ROSC_EXT_SYNC_BWIDTH_NARROW  (1) - 250 Hz
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetROSCExternalSyncBandwidth(ByRef Synchronization_Bandwidth As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetROSCExternalSyncBandwidth(Me._handle, Synchronization_Bandwidth)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the oscillator calibration value.
        '''
        '''Remote-control command(s):
        ''':CALibration:ROSCillator[:DATA]
        '''</summary>
        '''<param name="Data">
        '''This control sets the oscillator calibration value.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''0.0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetROSCCalibrationData(ByVal Data As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetROSCCalibrationData(Me._handle, Data)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the oscillator calibration value.
        '''
        '''Remote-control command(s):
        ''':CALibration:ROSCillator[:DATA]?
        '''
        '''</summary>
        '''<param name="Data">
        '''Displays the oscillator calibration value.
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetROSCCalibrationData(ByRef Data As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetROSCCalibrationData(Me._handle, Data)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function determines whether the calibrated (OFF) or a user-defined (ON) adjustment value is used for fine adjustment of the frequency. With STATe ON, the instrument is no longer in the calibrated state.
        '''
        '''Remote-control command(s):
        '''[SOURce:]ROSCillator[:INTernal]:ADJust[:STATe] ON | OFF
        '''</summary>
        '''<param name="Adjustment_Active">
        '''Activates/deactivates the pulse modulation.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_FALSE (0)
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetROSCAdjustmentActive(ByVal Adjustment_Active As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetROSCAdjustmentActive(Me._handle, System.Convert.ToUInt16(Adjustment_Active))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function determines whether the calibrated (OFF) or a user-defined (ON) adjustment value is used for fine adjustment of the frequency. With STATe ON, the instrument is no longer in the calibrated state.
        '''
        '''Remote-control command(s):
        '''[SOURce:]ROSCillator[:INTernal]:ADJust[:STATe]?
        '''</summary>
        '''<param name="Adjustment_Active">
        '''Determines whether the calibrated (OFF) or a user-defined (ON) adjustment value is used for fine adjustment of the frequency.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetROSCAdjustmentActive(ByRef Adjustment_Active As Boolean) As Integer
            Dim Adjustment_ActiveAsUShort As UShort
            Dim pInvokeResult As Integer = PInvoke.GetROSCAdjustmentActive(Me._handle, Adjustment_ActiveAsUShort)
            Adjustment_Active = System.Convert.ToBoolean(Adjustment_ActiveAsUShort)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function specifies the frequency correction value (adjustment value). A detailed definition is given in  section  RF Reference Frequency - Reference Oscillator.
        '''
        '''Remote-control command(s):
        '''[SOURce:]ROSCillator[:INTernal]:ADJust:VALue
        '''
        '''</summary>
        '''<param name="Adjustment_Value">
        '''Specifies the frequency correction value (adjustment value).
        '''
        '''Valid Range: 0 to 4095
        '''
        '''Default Value: 1400
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetROSCAdjustmentValue(ByVal Adjustment_Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetROSCAdjustmentValue(Me._handle, Adjustment_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the frequency correction value (adjustment value). A detailed definition is given in  section  RF Reference Frequency - Reference Oscillator.
        '''
        '''Remote-control command(s):
        '''[SOURce:]ROSCillator[:INTernal]:ADJust:VALue?
        '''
        '''</summary>
        '''<param name="Adjustment_Value">
        '''Returns the frequency correction value (adjustment value).
        '''
        '''Valid Range: 0 to 4095
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetROSCAdjustmentValue(ByRef Adjustment_Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetROSCAdjustmentValue(Me._handle, Adjustment_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the RF signal's power level
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer[:LEVel][:IMMediate][:AMPLitude]
        '''</summary>
        '''<param name="Level">
        '''This control sets the RF signal's power level.
        '''
        '''Valid Values:
        '''-130.0 to 30.0
        '''
        '''Default Value:
        '''-10.0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetLevel(ByVal Level As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetLevel(Me._handle, Level)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the level.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:LMODe AUTO | LNOise | LDIStortion
        '''[:SOURce:]POWer:SCHaracteristic AUTO | UNIN | MON | CPH
        '''[:SOURce:]POWer:LIMit[:AMPLitude]
        '''</summary>
        '''<param name="Mode">
        '''This control sets the level mode.
        '''
        '''Valid Values:
        '''RSSGS_LEVEL_MODE_AUTO (0) - Normal
        '''RSSGS_LEVEL_MODE_LNO  (1) - Low Noise
        '''RSSGS_LEVEL_MODE_LDIS (2) - Low Distortion
        '''
        '''Default Value:
        '''RSSGS_LEVEL_MODE_AUTO (0)
        '''</param>
        '''<param name="Setting_Characteristic">
        '''This control sets the characteristic for the level setting.
        '''
        '''Valid Values:
        '''RSSGS_LEVEL_SETT_CHARACT_AUTO (0) - Auto
        '''RSSGS_LEVEL_SETT_CHARACT_UNIN (1) - Uninterrupted Level Setting
        '''RSSGS_LEVEL_SETT_CHARACT_MON  (2) - Strictly Monotone
        '''RSSGS_LEVEL_SETT_CHARACT_CWSW (3) - Constant-VSWR
        '''
        '''
        '''Default Value:
        '''RSSGS_LEVEL_SETT_CHARACT_AUTO (0)
        '''</param>
        '''<param name="Limit">
        '''This control sets the upper limit of the RF signal power.
        '''
        '''Valid Values:
        '''-300.0 to 30.0
        '''
        '''Default Value:
        '''30.0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ConfigureLevelSettings(ByVal Mode As Integer, ByVal Setting_Characteristic As Integer, ByVal Limit As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureLevelSettings(Me._handle, Mode, Setting_Characteristic, Limit)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the level mode.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:LMODe AUTO | LNOise | LDIStortion
        '''</summary>
        '''<param name="Mode">
        '''This control sets the level mode.
        '''
        '''Valid Values:
        '''RSSGS_LEVEL_MODE_AUTO (0) - Normal
        '''RSSGS_LEVEL_MODE_LNO  (1) - Low Noise
        '''RSSGS_LEVEL_MODE_LDIS (2) - Low Distortion
        '''
        '''Default Value:
        '''RSSGS_LEVEL_MODE_AUTO (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetLevelMode(ByVal Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetLevelMode(Me._handle, Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the level mode.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:LMODe?
        '''
        '''</summary>
        '''<param name="Mode">
        '''Displays the level mode.
        '''
        '''Valid Values:
        '''RSSGS_LEVEL_MODE_AUTO (0) - Normal
        '''RSSGS_LEVEL_MODE_LNO  (1) - Low Noise
        '''RSSGS_LEVEL_MODE_LDIS (2) - Low Distortion
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetLevelMode(ByRef Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetLevelMode(Me._handle, Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the characteristic for the level setting.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:SCHaracteristic AUTO | UNIN | MON | CPH
        '''</summary>
        '''<param name="Setting_Characteristic">
        '''This control sets the characteristic for the level setting.
        '''
        '''Valid Values:
        '''RSSGS_LEVEL_SETT_CHARACT_AUTO (0) - Auto
        '''RSSGS_LEVEL_SETT_CHARACT_UNIN (1) - Uninterrupted Level Setting
        '''RSSGS_LEVEL_SETT_CHARACT_MON  (2) - Strictly Monotone
        '''RSSGS_LEVEL_SETT_CHARACT_CWSW (3) - Constant-VSWR
        '''
        '''
        '''Default Value: RSSGS_LEVEL_SETT_CHARACT_AUTO (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetLevelSettingCharacteristic(ByVal Setting_Characteristic As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetLevelSettingCharacteristic(Me._handle, Setting_Characteristic)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the characteristic for the level setting.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:SCHaracteristic?
        '''
        '''</summary>
        '''<param name="Setting_Characteristic">
        '''Displays the characteristic for the level setting.
        '''
        '''Valid Values:
        '''RSSGS_LEVEL_SETT_CHARACT_AUTO (0) - Auto
        '''RSSGS_LEVEL_SETT_CHARACT_UNIN (1) - Uninterrupted Level Setting
        '''RSSGS_LEVEL_SETT_CHARACT_MON  (2) - Strictly Monotone
        '''RSSGS_LEVEL_SETT_CHARACT_CWSW (3) - Constant-VSWR
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetLevelSettingCharacteristic(ByRef Setting_Characteristic As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetLevelSettingCharacteristic(Me._handle, Setting_Characteristic)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the RF signal's power level
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer[:LEVel][:IMMediate][:AMPLitude]?
        '''
        '''</summary>
        '''<param name="Level">
        '''Displays the RF signal's power level.
        '''
        '''Valid Values:
        '''-130.0 to 30.0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetLevel(ByRef Level As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetLevel(Me._handle, Level)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the upper limit of the RF signal power.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:LIMit[:AMPLitude]
        '''</summary>
        '''<param name="Limit">
        '''This control sets the upper limit of the RF signal power.
        '''
        '''Valid Values:
        '''-300.0 to 30.0
        '''
        '''Default Value:
        '''30.0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetLevelLimit(ByVal Limit As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetLevelLimit(Me._handle, Limit)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the upper limit of the RF signal power.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:LIMit[:AMPLitude]?
        '''
        '''</summary>
        '''<param name="Limit">
        '''Displays the upper limit of the RF signal power.
        '''
        '''Valid Values:
        '''-300.0 to 30.0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetLevelLimit(ByRef Limit As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetLevelLimit(Me._handle, Limit)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the state which the RF output assumes when the instrument is switched on.
        '''
        '''Remote-control command(s):
        ''':OUTPut[:STATe]:PON UNCHanged | OFF
        '''</summary>
        '''<param name="Power_On_State">
        '''This control sets the state which the RF output assumes when the instrument is switched on.
        '''
        '''Valid Values:
        '''RSSGS_LEVEL_POW_ON_OFF  (0) - RF Off
        '''RSSGS_LEVEL_POW_ON_UNCH (1) - Previous Setting
        '''
        '''Default Value:
        '''RSSGS_LEVEL_POW_ON_UNCH (1)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetLevelPowerOnState(ByVal Power_On_State As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetLevelPowerOnState(Me._handle, Power_On_State)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the state which the RF output assumes when the instrument is switched on.
        '''
        '''Remote-control command(s):
        ''':OUTPut[:STATe]:PON?
        '''
        '''</summary>
        '''<param name="Power_On_State">
        '''Displays the state which the RF output assumes when the instrument is switched on.
        '''
        '''Valid Values:
        '''RSSGS_LEVEL_POW_ON_OFF  (0) - RF Off
        '''RSSGS_LEVEL_POW_ON_UNCH (1) - Previous Setting
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetLevelPowerOnState(ByRef Power_On_State As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetLevelPowerOnState(Me._handle, Power_On_State)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the automatic level control.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:ALC[:STATe] ON | 1  | ONTable | OFFTable
        '''</summary>
        '''<param name="State">
        '''This control sets automatic level control.
        '''
        '''Valid Values:
        '''RSSGS_LEVEL_ALC_STATE_ONT  (0) - Table &amp; On
        '''RSSGS_LEVEL_ALC_STATE_ON   (1) - On
        '''RSSGS_LEVEL_ALC_STATE_OFFT (2) - Off (Table) 
        '''
        '''Default Value:
        '''RSSGS_LEVEL_ALC_STATE_ONT  (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetLevelALCState(ByVal State As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetLevelALCState(Me._handle, State)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the automatic level control.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:ALC[:STATe]?
        '''
        '''</summary>
        '''<param name="State">
        '''Displays the automatic level control.
        '''
        '''Valid Values:
        '''RSSGS_LEVEL_ALC_STATE_ONT  (0) - Table &amp; On
        '''RSSGS_LEVEL_ALC_STATE_ON   (1) - On
        '''RSSGS_LEVEL_ALC_STATE_OFFT (2) - Off (Table)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetLevelALCState(ByRef State As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetLevelALCState(Me._handle, State)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function activate level control for correction purposes.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:ALC:SONCe
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ReadjustLevelALC() As Integer
            Dim pInvokeResult As Integer = PInvoke.ReadjustLevelALC(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the state which the attenuator is to assume after the instrument is switched on.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:ATTenuation:RFOFf:MODE FIXed | MAX
        '''</summary>
        '''<param name="Mode">
        '''This control sets the state which the attenuator is to assume after the instrument is switched on.
        '''
        '''Valid Values:
        '''RSSGS_LEVEL_ATT_ON_FIX (0) - Fixed
        '''RSSGS_LEVEL_ATT_ON_MAX (1) - Maximum
        '''
        '''Default Value:
        '''RSSGS_LEVEL_ATT_ON_MAX (1)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetAttenuatorModeAfterOn(ByVal Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetAttenuatorModeAfterOn(Me._handle, Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the state which the attenuator is to assume after the instrument is switched on.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:ATTenuation:RFOFf:MODE?
        '''
        '''</summary>
        '''<param name="Mode">
        '''Displays the state which the attenuator is to assume after the instrument is switched on.
        '''
        '''Valid Values:
        '''RSSGS_LEVEL_ATT_ON_FIX (0) - Fixed
        '''RSSGS_LEVEL_ATT_ON_MAX (1) - Maximum
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetAttenuatorModeAfterOn(ByRef Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetAttenuatorModeAfterOn(Me._handle, Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the switch-over offset value of the attenuator.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:ATTenuation:SOVer[:OFFSet]
        '''</summary>
        '''<param name="Offset">
        '''This control sets the switch-over offset value of the attenuator.
        '''
        '''Valid Values:
        '''-10.0 to 10.0
        '''
        '''Default Value:
        '''0.0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetAttenuatorSwitchOverOffset(ByVal Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetAttenuatorSwitchOverOffset(Me._handle, Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the switch-over offset value of the attenuator.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]POWer:ATTenuation:SOVer[:OFFSet]?
        '''
        '''</summary>
        '''<param name="Offset">
        '''Displays the switch-over offset value of the attenuator.
        '''
        '''Valid Values:
        '''-10.0 to 10.0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetAttenuatorSwitchOverOffset(ByRef Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetAttenuatorSwitchOverOffset(Me._handle, Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the minimum level which can be set without the attenuator being adjusted (Attenuator FIXed).
        '''
        '''Remote-control command(s):
        '''OUTPut:AFIXed:RANGe:LOWer?
        '''</summary>
        '''<param name="Attenuator_Lower_Range">
        '''Returns the minimum level which can be set without the attenuator being adjusted (Attenuator FIXed).
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetAttenuatorLowerRange(ByRef Attenuator_Lower_Range As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetAttenuatorLowerRange(Me._handle, Attenuator_Lower_Range)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the maximum level which can be set without the attenuator being adjusted (Attenuator FIXed).
        '''
        '''Remote-control command(s):
        '''OUTPut:AFIXed:RANGe:UPPer?
        '''</summary>
        '''<param name="Attenuator_Upper_Range">
        '''Returns the maximum level which can be set without the attenuator being adjusted (Attenuator FIXed).
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetAttenuatorUpperRange(ByRef Attenuator_Upper_Range As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetAttenuatorUpperRange(Me._handle, Attenuator_Upper_Range)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the IQ modulator.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]MODulator:STATe
        '''[:SOURce:]BB:IMPairment:IQWBand[:STATe]
        '''</summary>
        '''<param name="IQ_Modulator_State">
        '''This control sets the state of the IQ modulator.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value:
        '''VI_FALSE (0)
        '''</param>
        '''<param name="IQ_Wideband">
        '''This control sets optimized settings for wideband modulation signals.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value:
        '''VI_FALSE (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ConfigureIQ(ByVal IQ_Modulator_State As Boolean, ByVal IQ_Wideband As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureIQ(Me._handle, System.Convert.ToUInt16(IQ_Modulator_State), System.Convert.ToUInt16(IQ_Wideband))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the IQ Impairments.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:STATe
        '''[:SOURce:]IQ:IMPairment:LEAKage:I
        '''[:SOURce:]IQ:IMPairment:LEAKage:Q
        '''[:SOURce:]IQ:IMPairment:IQRatio
        '''[:SOURce:]IQ:IMPairment:QUADrature[:ANGLe]
        '''</summary>
        '''<param name="State">
        '''This control sets the impairment or correction values LEAKage, QUADrature and IQRatio for the digital baseband signal.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value:
        '''VI_FALSE (0)
        '''</param>
        '''<param name="I_Offset">
        '''This control sets the carrier offset for the I-channel of the I/Q modulation.
        '''
        '''Valid Values:
        '''-10.00 to 10.00
        '''
        '''Default Value:
        '''0.00
        '''</param>
        '''<param name="Q_Offset">
        '''This control sets the carrier offset for the Q-channel of the I/Q modulation.
        '''
        '''Valid Values:
        '''-10.00 to 10.00
        '''
        '''Default Value:
        '''0.00
        '''</param>
        '''<param name="Gain_Imbalance">
        '''This control sets the ratio of I modulation to Q modulation (gain imbalance).
        '''
        '''Valid Values:
        '''-1.000 to 1.000
        '''
        '''Default Value:
        '''0.000
        '''</param>
        '''<param name="Quadrature_Offset">
        '''This control sets the quadrature offset for the digital I/Q signal.
        '''
        '''Valid Values:
        '''-10.00 to 10.00
        '''
        '''Default Value:
        '''0.00
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ConfigureIQImpairments(ByVal State As Boolean, ByVal I_Offset As Double, ByVal Q_Offset As Double, ByVal Gain_Imbalance As Double, ByVal Quadrature_Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureIQImpairments(Me._handle, System.Convert.ToUInt16(State), I_Offset, Q_Offset, Gain_Imbalance, Quadrature_Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the state of the IQ modulator.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]MODulator:STATe
        '''</summary>
        '''<param name="IQ_Modulator_State">
        '''This control sets the state of the IQ modulator.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value:
        '''VI_FALSE (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetIQModulatorState(ByVal IQ_Modulator_State As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetIQModulatorState(Me._handle, System.Convert.ToUInt16(IQ_Modulator_State))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the state of the IQ modulator.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]MODulator:STATe?
        '''</summary>
        '''<param name="IQ_Modulator_State">
        '''Displays the state of the IQ modulator.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetIQModulatorState(ByRef IQ_Modulator_State As Boolean) As Integer
            Dim IQ_Modulator_StateAsUShort As UShort
            Dim pInvokeResult As Integer = PInvoke.GetIQModulatorState(Me._handle, IQ_Modulator_StateAsUShort)
            IQ_Modulator_State = System.Convert.ToBoolean(IQ_Modulator_StateAsUShort)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the impairment or correction values LEAKage, QUADrature and IQRatio for the digital baseband signal.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:STATe
        '''</summary>
        '''<param name="State">
        '''This control sets the impairment or correction values LEAKage, QUADrature and IQRatio for the digital baseband signal.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value:
        '''VI_FALSE (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetIQImpairmentsState(ByVal State As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetIQImpairmentsState(Me._handle, System.Convert.ToUInt16(State))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the impairment or correction values LEAKage, QUADrature and IQRatio for the digital baseband signal.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:STATe?
        '''</summary>
        '''<param name="State">
        '''Displays the impairment or correction values LEAKage, QUADrature and IQRatio for the digital baseband signal.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetIQImpairmentsState(ByRef State As Boolean) As Integer
            Dim StateAsUShort As UShort
            Dim pInvokeResult As Integer = PInvoke.GetIQImpairmentsState(Me._handle, StateAsUShort)
            State = System.Convert.ToBoolean(StateAsUShort)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the carrier offset for the I-channel of the I/Q modulation.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:LEAKage:I
        '''</summary>
        '''<param name="I_Offset">
        '''This control sets the carrier offset for the I-channel of the I/Q modulation.
        '''
        '''Valid Values:
        '''-10.00 to 10.00
        '''
        '''Default Value:
        '''0.00
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetIQImpairmentsIOffset(ByVal I_Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetIQImpairmentsIOffset(Me._handle, I_Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the carrier offset for the I-channel of the I/Q modulation.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:LEAKage:I?
        '''</summary>
        '''<param name="I_Offset">
        '''Displays the carrier offset for the I-channel of the I/Q modulation.
        '''
        '''Valid Values:
        '''-10.00 to 10.00
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetIQImpairmentsIOffset(ByRef I_Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetIQImpairmentsIOffset(Me._handle, I_Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the carrier offset for the Q-channel of the I/Q modulation.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:LEAKage:Q
        '''</summary>
        '''<param name="Q_Offset">
        '''This control sets the carrier offset for the Q-channel of the I/Q modulation.
        '''
        '''Valid Values:
        '''-10.00 to 10.00
        '''
        '''Default Value:
        '''0.00
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetIQImpairmentsQOffset(ByVal Q_Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetIQImpairmentsQOffset(Me._handle, Q_Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the carrier offset for the Q-channel of the I/Q modulation.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:LEAKage:Q?
        '''</summary>
        '''<param name="Q_Offset">
        '''Displays the carrier offset for the Q-channel of the I/Q modulation.
        '''
        '''Valid Values:
        '''-10.00 to 10.00
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetIQImpairmentsQOffset(ByRef Q_Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetIQImpairmentsQOffset(Me._handle, Q_Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the ratio of I modulation to Q modulation (gain imbalance).
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:IQRatio
        '''</summary>
        '''<param name="Gain_Imbalance">
        '''This control sets the ratio of I modulation to Q modulation (gain imbalance).
        '''
        '''Valid Values:
        '''-1.000 to 1.000
        '''
        '''Default Value:
        '''0.000
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetIQImpairmentsGainImbalance(ByVal Gain_Imbalance As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetIQImpairmentsGainImbalance(Me._handle, Gain_Imbalance)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the ratio of I modulation to Q modulation (gain imbalance).
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:IQRatio?
        '''</summary>
        '''<param name="Gain_Imbalance">
        '''Displays the ratio of I modulation to Q modulation (gain imbalance).
        '''
        '''Valid Values:
        '''-1.000 to 1.000
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetIQImpairmentsGainImbalance(ByRef Gain_Imbalance As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetIQImpairmentsGainImbalance(Me._handle, Gain_Imbalance)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the quadrature offset for the digital I/Q signal.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:QUADrature[:ANGLe]
        '''</summary>
        '''<param name="Quadrature_Offset">
        '''This control sets the quadrature offset for the digital I/Q signal.
        '''
        '''Valid Values:
        '''-10.00 to 10.00
        '''
        '''Default Value:
        '''0.00
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetIQImpairmentsQuadratureOffset(ByVal Quadrature_Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetIQImpairmentsQuadratureOffset(Me._handle, Quadrature_Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the quadrature offset for the digital I/Q signal.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:QUADrature[:ANGLe]?
        '''</summary>
        '''<param name="Quadrature_Offset">
        '''Displays the quadrature offset for the digital I/Q signal.
        '''
        '''Valid Values:
        '''-10.00 to 10.00
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetIQImpairmentsQuadratureOffset(ByRef Quadrature_Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetIQImpairmentsQuadratureOffset(Me._handle, Quadrature_Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets optimized settings for wideband modulation signals.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:IQWBand[:STATe]
        '''</summary>
        '''<param name="IQ_Wideband">
        '''This control sets optimized settings for wideband modulation signals.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value:
        '''VI_FALSE (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetIQWideband(ByVal IQ_Wideband As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetIQWideband(Me._handle, System.Convert.ToUInt16(IQ_Wideband))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries optimized settings for wideband modulation signals.
        '''
        '''Remote-control command(s):
        '''[:SOURce:]IQ:IMPairment:IQWBand[:STATe]?
        '''</summary>
        '''<param name="IQ_Wideband">
        '''Displays optimized settings for wideband modulation signals.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetIQWideband(ByRef IQ_Wideband As Boolean) As Integer
            Dim IQ_WidebandAsUShort As UShort
            Dim pInvokeResult As Integer = PInvoke.GetIQWideband(Me._handle, IQ_WidebandAsUShort)
            IQ_Wideband = System.Convert.ToBoolean(IQ_WidebandAsUShort)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the SGU extension module.
        '''
        '''Remote-control command(s):
        ''':EXTension:ACTive:STATe
        ''':EXTension:REMote:CHANnel LAN | USB | PCIE | SOCKet
        ''':EXTension:REMote:LAN:NAME
        ''':EXTension:SERial
        '''</summary>
        '''<param name="State">
        '''This control sets the state of the SGU extension module.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value:
        '''VI_FALSE (0)
        '''</param>
        '''<param name="Hardware_Channel">
        '''This control sets the channel of the SGU extension device.
        '''
        '''Valid Values:
        '''RSSGS_SGU_HW_CHANN_LAN  (0) - LAN
        '''RSSGS_SGU_HW_CHANN_USB  (1) - USB
        '''RSSGS_SGU_HW_CHANN_PCIE (2) - PCIe
        '''RSSGS_SGU_HW_CHANN_SOCK (3) - Socket
        '''
        '''Default Value:
        '''RSSGS_SGU_HW_CHANN_LAN  (0)
        '''</param>
        '''<param name="Instrument_Name">
        '''This control sets the LAN IP address / instrument name of the SGU extension device.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''""
        '''
        '''Note(s):
        '''This control is valid only for Hardware Channel LAN and Socket.
        '''</param>
        '''<param name="Serial_Number">
        '''This control sets the Serial number of the SGU extension  (for USB and PCIe).
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''100001
        '''
        '''Note(s):
        '''This control is valid only for Hardware Channel USB and PCIe.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ConfigureExtension(ByVal State As Boolean, ByVal Hardware_Channel As Integer, ByVal Instrument_Name As String, ByVal Serial_Number As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureExtension(Me._handle, System.Convert.ToUInt16(State), Hardware_Channel, Instrument_Name, Serial_Number)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the state of the SGU extension module.
        '''
        '''Remote-control command(s):
        ''':EXTension:ACTive:STATe
        '''</summary>
        '''<param name="State">
        '''This control sets the state of the SGU extension module.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value:
        '''VI_FALSE (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetExtensionState(ByVal State As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetExtensionState(Me._handle, System.Convert.ToUInt16(State))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the state of the SGU extension module.
        '''
        '''Remote-control command(s):
        ''':EXTension:ACTive:STATe?
        '''</summary>
        '''<param name="State">
        '''Displays the state of the SGU extension module.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetExtensionState(ByRef State As Boolean) As Integer
            Dim StateAsUShort As UShort
            Dim pInvokeResult As Integer = PInvoke.GetExtensionState(Me._handle, StateAsUShort)
            State = System.Convert.ToBoolean(StateAsUShort)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the channel of the SGU extension device.
        '''
        '''Remote-control command(s):
        ''':EXTension:REMote:CHANnel LAN | USB | PCIE | SOCKet
        '''</summary>
        '''<param name="Hardware_Channel">
        '''This control sets the channel of the SGU extension device.
        '''
        '''Valid Values:
        '''RSSGS_SGU_HW_CHANN_LAN  (0) - LAN
        '''RSSGS_SGU_HW_CHANN_USB  (1) - USB
        '''RSSGS_SGU_HW_CHANN_PCIE (2) - PCIe
        '''RSSGS_SGU_HW_CHANN_SOCK (3) - Socket
        '''
        '''Default Value:
        '''RSSGS_SGU_HW_CHANN_LAN  (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetExtensionHardwareChannel(ByVal Hardware_Channel As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetExtensionHardwareChannel(Me._handle, Hardware_Channel)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the channel of the SGU extension device.
        '''
        '''Remote-control command(s):
        ''':EXTension:REMote:CHANnel?
        '''</summary>
        '''<param name="Hardware_Channel">
        '''Displays the channel of the SGU extension device.
        '''
        '''Valid Values:
        '''RSSGS_SGU_HW_CHANN_LAN  (0) - LAN
        '''RSSGS_SGU_HW_CHANN_USB  (1) - USB
        '''RSSGS_SGU_HW_CHANN_PCIE (2) - PCIe
        '''RSSGS_SGU_HW_CHANN_SOCK (3) - Socket
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetExtensionHardwareChannel(ByRef Hardware_Channel As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetExtensionHardwareChannel(Me._handle, Hardware_Channel)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the LAN IP address / instrument name of the SGU extension device.
        '''
        '''Remote-control command(s):
        ''':EXTension:REMote:LAN:NAME
        '''</summary>
        '''<param name="Instrument_Name">
        '''This control sets the LAN IP address / instrument name of the SGU extension device.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''""
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetExtensionInstrumentName(ByVal Instrument_Name As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetExtensionInstrumentName(Me._handle, Instrument_Name)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the LAN IP address / instrument name of the SGU extension device.
        '''
        '''Remote-control command(s):
        ''':EXTension:REMote:LAN:NAME?
        '''</summary>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="Instrument_Name">
        '''Displays the LAN IP address / instrument name of the SGU extension device.
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetExtensionInstrumentName(ByVal Array_Size As Integer, ByVal Instrument_Name As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetExtensionInstrumentName(Me._handle, Array_Size, Instrument_Name)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the Serial number of the SGU extension  (for USB and PCIe).
        '''
        '''Remote-control command(s):
        ''':EXTension:SERial
        '''</summary>
        '''<param name="Serial_Number">
        '''This control sets the Serial number of the SGU extension  (for USB and PCIe).
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''100001
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetExtensionSerialNumber(ByVal Serial_Number As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetExtensionSerialNumber(Me._handle, Serial_Number)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the Serial number of the SGU extension  (for USB and PCIe).
        '''
        '''Remote-control command(s):
        ''':EXTension:SERial?
        '''</summary>
        '''<param name="Serial_Number">
        '''Displays the Serial number of the SGU extension  (for USB and PCIe).
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetExtensionSerialNumber(ByRef Serial_Number As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetExtensionSerialNumber(Me._handle, Serial_Number)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the state of the SGU extension device.
        '''
        '''Remote-control command(s):
        ''':EXTension:REMote:STATe?
        '''</summary>
        '''<param name="Remote_State">
        '''Displays the state of the SGU extension device.
        '''
        '''Valid Values:
        '''0 - not connected
        '''1 - connected
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetExtensionRemoteState(ByRef Remote_State As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetExtensionRemoteState(Me._handle, Remote_State)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the busy state of the SGU extension device.
        '''
        '''Remote-control command(s):
        ''':EXTension:BUSY:STATe?
        '''</summary>
        '''<param name="Busy_State">
        '''Displays the busy state of the SGU extension device.
        '''
        '''Valid Values:
        '''0 - not bussy
        '''1 - bussy
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetExtensionBusyState(ByRef Busy_State As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetExtensionBusyState(Me._handle, Busy_State)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function pass a lock request id which uniquely identifies the controller to the instrument.
        '''
        '''Remote-control command(s):
        '''LOCK?
        '''</summary>
        '''<param name="Lock_ID">
        '''This control uniquely identifies the controller to the instrument.
        '''
        '''Valid Values: 
        '''Not Checked
        '''
        '''Default Value:
        '''0
        '''
        '''</param>
        '''<param name="Result">
        '''Pass a lock request id which uniquely identifies the controller to the instrument.
        '''
        '''Valid Values:
        '''0 - Request refused
        '''1 - Request granted
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function LockInstrument(ByVal Lock_ID As Integer, ByRef Result As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.LockInstrument(Me._handle, Lock_ID, Result)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function unlock device.
        '''
        '''Remote-control command(s):
        '''UNLock
        '''</summary>
        '''<param name="Lock_ID">
        '''This control uniquely identifies the controller to the instrument.
        '''
        '''Valid Values: 
        '''Not Checked
        '''
        '''Default Value:
        '''0
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function UnlockInstrument(ByVal Lock_ID As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.UnlockInstrument(Me._handle, Lock_ID)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function perform all internal adjustments.
        '''
        '''Note:
        '''
        '''If the calibration fails, this function returns an error code.
        '''
        '''Remote-control command(s):
        '''CALibration:ALL?
        '''*OPC?
        '''</summary>
        '''<param name="Timeout">
        '''Sets the timeout for the calibration routine to be finished and have obtained calibration result. If the length of time required for calibration exceeds the timeout value, then the function will return with a timeout error and the instrument will continue with calibration.
        '''
        '''Valid Range: 0 ms to 600000 ms
        '''
        '''Default Value: 180000 ms
        '''
        '''</param>
        '''<param name="Result">
        '''Returns result of the adjustment. The response "0" indicates error-free adjustment, and the response "1" means that an error occurred during adjustment.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function CALibrationAll(ByVal Timeout As Integer, ByRef Result As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.CALibrationAll(Me._handle, Timeout, Result)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function perform internal level adjustment.
        '''
        '''Note:
        '''If the calibration fails, this function returns an error code.
        '''
        '''
        '''Remote-control command(s):
        '''CALibration:LEVel[:MEASure]?
        '''*OPC?
        '''</summary>
        '''<param name="Timeout">
        '''Sets the timeout for the calibration routine to be finished and have obtained calibration result. If the length of time required for calibration exceeds the timeout value, then the function will return with a timeout error and the instrument will continue with calibration.
        '''
        '''Valid Range: 0 ms to 600000 ms
        '''
        '''Default Value: 180000 ms
        '''
        '''</param>
        '''<param name="Result">
        '''Returns result of the adjustment. The response "0" indicates error-free adjustment, and the response "1" means that an error occurred during adjustment.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function CALibrationLevel(ByVal Timeout As Integer, ByRef Result As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.CALibrationLevel(Me._handle, Timeout, Result)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function performs all adjustments which affect the frequency.
        '''
        '''Note:
        '''If the calibration fails, this function returns an error code.
        '''
        '''Remote-control command(s):
        '''CAL:FREQ?
        '''*OPC?
        '''</summary>
        '''<param name="Timeout">
        '''Sets the timeout for the calibration routine to be finished and have obtained calibration result. If the length of time required for calibration exceeds the timeout value, then the function will return with a timeout error and the instrument will continue with calibration.
        '''
        '''Valid Range: 0 ms to 600000 ms
        '''
        '''Default Value: 180000 ms
        '''
        '''</param>
        '''<param name="Result">
        '''Returns result of the adjustment. The response "0" indicates error-free adjustment, and the response "1" means that an error occurred during adjustment.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function CALibrationSynthesis(ByVal Timeout As Integer, ByRef Result As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.CALibrationSynthesis(Me._handle, Timeout, Result)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function starts the adjustment for the I/Q modulator for the entire frequency range. The I/Q modulator is adjusted with respect to carrier leakage, I/Q imbalance and quadrature.
        '''
        '''Note:
        '''If the calibration fails, this function returns an error code.
        '''
        '''Remote-control command(s):
        '''CALibration:MODulator?
        '''*OPC?
        '''</summary>
        '''<param name="Timeout">
        '''Sets the timeout for the calibration routine to be finished and have obtained calibration result. If the length of time required for calibration exceeds the timeout value, then the function will return with a timeout error and the instrument will continue with calibration.
        '''
        '''Valid Range: 0 ms to 600000 ms
        '''
        '''Default Value: 180000 ms
        '''
        '''</param>
        '''<param name="Result">
        '''Returns result of the adjustment. The response "0" indicates error-free adjustment, and the response "1" means that an error occurred during adjustment.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function CALibrationIQModulator(ByVal Timeout As Integer, ByRef Result As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.CALibrationIQModulator(Me._handle, Timeout, Result)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function starts the adjustment for the I/Q modulator for the current frequency. The I/Q modulator is adjusted with respect to carrier leakage, I/Q imbalance and quadrature.
        '''
        '''Remote-control command(s):
        '''CALibration:MODulator:CFRequency?
        '''*OPC?
        '''</summary>
        '''<param name="Timeout">
        '''Sets the timeout for the calibration routine to be finished and have obtained calibration result. If the length of time required for calibration exceeds the timeout value, then the function will return with a timeout error and the instrument will continue with calibration.
        '''
        '''Valid Range: 0 ms to 600000 ms
        '''
        '''Default Value: 180000 ms
        '''
        '''</param>
        '''<param name="Result">
        '''Returns result of the adjustment. The response "0" indicates error-free adjustment, and the response "1" means that an error occurred during adjustment.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function CALibrationIQModulatorForCurrentFrequency(ByVal Timeout As Integer, ByRef Result As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.CALibrationIQModulatorForCurrentFrequency(Me._handle, Timeout, Result)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function gets network settings from system.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork:GET
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetNetworkSystemSettings() As Integer
            Dim pInvokeResult As Integer = PInvoke.GetNetworkSystemSettings(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the MAC Address.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork:MACaddress?
        '''</summary>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="MAC_Address">
        '''Displays the MAC Address.
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetNetworkMACAddress(ByVal Array_Size As Integer, ByVal MAC_Address As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetNetworkMACAddress(Me._handle, Array_Size, MAC_Address)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the IP Address.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork:IPADdress:MODE STATic | AUTO
        ''':SYSTem:COMMunicate:NETWork:IPADdress
        ''':SYSTem:COMMunicate:NETWork[:IPADdress]:SUBNet:MASK
        ''':SYSTem:COMMunicate:NETWork[:IPADdress]:GATeway
        '''</summary>
        '''<param name="Address_Mode">
        '''This control sets the IP Address Mode.
        '''
        '''Valid Values:
        '''RSSGS_IP_ADDRESS_MODE_AUTO (0) - Auto (DHCP)
        '''RSSGS_IP_ADDRESS_MODE_STAT (1) - Static
        '''
        '''Default Value:
        '''RSSGS_IP_ADDRESS_MODE_AUTO (0)
        '''</param>
        '''<param name="IP_Address">
        '''This control sets the IP Address.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''"0.0.0.0"
        '''</param>
        '''<param name="Subnet_Mask">
        '''This control sets the Subnet Mask.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''"0.0.0.0"
        '''</param>
        '''<param name="Default_Gateway">
        '''This control sets the Default Gateway.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''"0.0.0.0"
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ConfigureNetworkIP(ByVal Address_Mode As Integer, ByVal IP_Address As String, ByVal Subnet_Mask As String, ByVal Default_Gateway As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureNetworkIP(Me._handle, Address_Mode, IP_Address, Subnet_Mask, Default_Gateway)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the resource string.
        '''
        '''Remote-control command(s):
        '''SYSTem:COMMunicate:NETWork:RESource?
        '''</summary>
        '''<param name="Array_Size">
        '''Array size of the parameter labeled 'Resource'.
        '''
        '''Valid Range: &gt; 0
        '''
        '''Default Value: 256
        '''
        '''</param>
        '''<param name="Resource">
        '''This control displays the resource string.
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetNetworkResource(ByVal Array_Size As UInteger, ByVal Resource As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetNetworkResource(Me._handle, Array_Size, Resource)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the network configuration state.
        '''
        '''Remote-control command(s):
        '''SYSTem:COMMunicate:NETWork:STATus?
        '''</summary>
        '''<param name="Configuration">
        '''This control displays the network configuration state.
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetNetworkConfigurationState(ByRef Configuration As Boolean) As Integer
            Dim ConfigurationAsUShort As UShort
            Dim pInvokeResult As Integer = PInvoke.GetNetworkConfigurationState(Me._handle, ConfigurationAsUShort)
            Configuration = System.Convert.ToBoolean(ConfigurationAsUShort)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the Hostname of the network.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork[:COMMon]:HOSTname
        '''</summary>
        '''<param name="Hostname">
        '''This control sets the Hostname of the network.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''"Undefined"
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetNetworkCommonHostname(ByVal Hostname As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetNetworkCommonHostname(Me._handle, Hostname)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the Hostname of the network.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork[:COMMon]:HOSTname?
        '''</summary>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="Hostname">
        '''Displays the Hostname of the network.
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetNetworkCommonHostname(ByVal Array_Size As Integer, ByVal Hostname As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetNetworkCommonHostname(Me._handle, Array_Size, Hostname)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the IP Address Mode.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork:IPADdress:MODE STATic | AUTO
        '''</summary>
        '''<param name="Address_Mode">
        '''This control sets the IP Address Mode.
        '''
        '''Valid Values:
        '''RSSGS_IP_ADDRESS_MODE_AUTO (0) - Auto (DHCP)
        '''RSSGS_IP_ADDRESS_MODE_STAT (1) - Static
        '''
        '''Default Value:
        '''RSSGS_IP_ADDRESS_MODE_AUTO (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetNetworkIPAddressMode(ByVal Address_Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetNetworkIPAddressMode(Me._handle, Address_Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the IP Address Mode.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork:IPADdress:MODE?
        '''</summary>
        '''<param name="Address_Mode">
        '''Displays the IP Address Mode.
        '''
        '''Valid Values:
        '''RSSGS_IP_ADDRESS_MODE_AUTO (0) - Auto (DHCP)
        '''RSSGS_IP_ADDRESS_MODE_STAT (1) - Static
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetNetworkIPAddressMode(ByRef Address_Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetNetworkIPAddressMode(Me._handle, Address_Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the IP Adrress.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork:IPADdress
        '''</summary>
        '''<param name="IP_Address">
        '''This control sets the IP Address.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''"0.0.0.0"
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetNetworkIPAddress(ByVal IP_Address As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetNetworkIPAddress(Me._handle, IP_Address)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the IP Adrress.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork:IPADdress?
        '''</summary>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="IP_Address">
        '''Displays the IP Address.
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetNetworkIPAddress(ByVal Array_Size As Integer, ByVal IP_Address As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetNetworkIPAddress(Me._handle, Array_Size, IP_Address)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the Subnet Mask.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork[:IPADdress]:SUBNet:MASK
        '''</summary>
        '''<param name="Subnet_Mask">
        '''This control sets the Subnet Mask.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''"0.0.0.0"
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetNetworkIPSubnetMask(ByVal Subnet_Mask As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetNetworkIPSubnetMask(Me._handle, Subnet_Mask)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the Subnet Mask.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork[:IPADdress]:SUBNet:MASK?
        '''</summary>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="Subnet_Mask">
        '''Displays the Subnet Mask.
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetNetworkIPSubnetMask(ByVal Array_Size As Integer, ByVal Subnet_Mask As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetNetworkIPSubnetMask(Me._handle, Array_Size, Subnet_Mask)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the Default Gateway.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork[:IPADdress]:GATeway
        '''</summary>
        '''<param name="Default_Gateway">
        '''This control sets the Default Gateway.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''"0.0.0.0"
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetNetworkIPDefaultGateway(ByVal Default_Gateway As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetNetworkIPDefaultGateway(Me._handle, Default_Gateway)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the Default Gateway.
        '''
        '''Remote-control command(s):
        ''':SYSTem:COMMunicate:NETWork[:IPADdress]:GATeway?
        '''</summary>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="Default_Gateway">
        '''Displays the Default Gateway.
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetNetworkIPDefaultGateway(ByVal Array_Size As Integer, ByVal Default_Gateway As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetNetworkIPDefaultGateway(Me._handle, Array_Size, Default_Gateway)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function accepts the IP Address Settings.
        '''
        '''Remote-control command(s):
        '''SYSTem:COMMunicate:NETWork:IPADdress:SET
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function AcceptNetworkIPSettings() As Integer
            Dim pInvokeResult As Integer = PInvoke.AcceptNetworkIPSettings(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the remote control operation mode.
        '''
        '''Remote-control command(s):
        ''':REMote:OPMode EXTension | STDalone
        '''</summary>
        '''<param name="Operation_Mode">
        '''This control sets the remote control operation mode.
        '''
        '''Valid Values:
        '''RSSGS_REMOTE_OPER_MODE_EXT (0) - Extension
        '''RSSGS_REMOTE_OPER_MODE_STD (1) - Stand Alone 
        '''
        '''Default Value:
        '''RSSGS_REMOTE_OPER_MODE_EXT (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetRemoteOperationMode(ByVal Operation_Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetRemoteOperationMode(Me._handle, Operation_Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the remote control operation mode.
        '''
        '''Remote-control command(s):
        ''':REMote:OPMode?
        '''
        '''</summary>
        '''<param name="Operation_Mode">
        '''Displays the remote control operation mode.
        '''
        '''Valid Values:
        '''RSSGS_REMOTE_OPER_MODE_EXT (0) - Extension
        '''RSSGS_REMOTE_OPER_MODE_STD (1) - Stand Alone
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetRemoteOperationMode(ByRef Operation_Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetRemoteOperationMode(Me._handle, Operation_Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''CLEAR STATUS sets the status byte (STB), the standard event register (ESR), and the EVENt part of the QUEStionable and OPERation register to zero. The function does not change the enable and transition parts of the registers. It deletes the output buffer.
        '''
        '''Remote-control command(s):
        '''*CLS
        '''
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ClearStatus() As Integer
            Dim pInvokeResult As Integer = PInvoke.ClearStatus(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''EVENT STATUS ENABLE sets the event status enable register to the specified value. The *ESE? query command returns the content of the event status enable register in decimal form.
        '''
        '''Remote-control command(s):
        '''*ESE
        '''
        '''</summary>
        '''<param name="Register_Value">
        '''EVENT STATUS ENABLE sets the event status enable register to the specified value.
        '''
        '''Valid Range: 0 to 255
        '''
        '''Default Value: 0
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function EventStatusEnable(ByVal Register_Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.EventStatusEnable(Me._handle, Register_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''STANDARD EVENT STATUS QUERY returns the content of the event status register in decimal form (0...255) and then sets the register to zero.
        '''
        '''Remote-control command(s):
        '''*ESR?
        '''
        '''</summary>
        '''<param name="Register_Value">
        '''Returns the content of the event status register in decimal form (0...255).
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function EventStatusQuery(ByRef Register_Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.EventStatusQuery(Me._handle, Register_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''IDENTIFICATION QUERY queries the instrument identification. The instrument type, serial number and firmware version are returned.
        '''
        '''Example:
        '''
        '''"Rohde&amp;Schwarz,SMB100A,1141.2005k02/123456,1.00.0.0 (Release)"
        '''
        '''Remote-control command(s):
        '''*IDN?
        '''
        '''</summary>
        '''<param name="Instrument_Identification">
        '''Returns the instrument identification string.
        '''
        '''Notes:
        '''
        '''(1) The array must contain at least 256 elements ViChar[256].
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function IdentificationQuery(ByVal Instrument_Identification As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.IdentificationQuery(Me._handle, Instrument_Identification)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''INDIVIDUAL STATUS QUERY returns the content of the IST flag in decimal form (0 | 1). The IST flag is the status bit which is sent during a parallel poll.
        '''
        '''Remote-control command(s):
        '''*IST?
        '''
        '''</summary>
        '''<param name="IST_Flag">
        '''Returns the content of the IST flag in decimal form (0 | 1).
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function IndividualStatusQuery(ByRef IST_Flag As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.IndividualStatusQuery(Me._handle, IST_Flag)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''OPERATION COMPLETE sets bit 0 in the event status register when all previous commands have been processed. This bit can be used to trigger a service request.
        '''
        '''Remote-control command(s):
        '''*OPC
        '''
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function OperationComplete() As Integer
            Dim pInvokeResult As Integer = PInvoke.OperationComplete(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''OPERATION COMPLETE QUERY returns a 1 when all previous commands have been processed. It is important to ensure that the timeout set at the IEC/IEEE bus is long enough.
        '''
        '''Remote-control command(s):
        '''*OPC?
        '''
        '''</summary>
        '''<param name="OPC_State">
        '''Returns a 1 when all previous commands have been processed.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function OperationCompleteQuery(ByRef OPC_State As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.OperationCompleteQuery(Me._handle, OPC_State)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''OPTION IDENTIFICATION QUERY queries the options configured in the instrument and returns a list of the installed options. The options are separated by commas. 
        '''
        '''Remote-control command(s):
        '''*OPT?
        '''
        '''</summary>
        '''<param name="Option_Identification">
        '''Returns a list of the installed options.
        '''
        '''Notes:
        '''
        '''(1) The array must contain at least 1024 elements ViChar[1024].
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function OptionIdentificationQuery(ByVal Option_Identification As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.OptionIdentificationQuery(Me._handle, Option_Identification)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''PARALLEL POLL REGISTER ENABLE sets the parallel poll enable register to the specified value. The *PRE? query command returns the content of the parallel poll enable register in decimal form.
        '''
        '''Remote-control command(s):
        '''*PRE
        '''
        '''</summary>
        '''<param name="Register_Value">
        '''Sets the parallel poll enable register to the specified value.
        '''
        '''Valid Range: 0 to 655
        '''
        '''Default Value: 0
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ParallelPollRegisterEnable(ByVal Register_Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ParallelPollRegisterEnable(Me._handle, Register_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''PARALLEL POLL REGISTER QUERY returns the content of the parallel poll enable register in decimal form.
        '''
        '''Remote-control command(s):
        '''*PRE?
        '''
        '''</summary>
        '''<param name="Register_Value">
        '''Returns the content of the parallel poll enable register in decimal form.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ParallelPollRegisterQuery(ByRef Register_Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ParallelPollRegisterQuery(Me._handle, Register_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''POWER ON STATUS CLEAR determines whether the content of the ENABle registers are retained or reset at power on.
        '''
        '''The query *PSC? retrieves the contents of the Power-on-Status-Clear flag. The answer is either 0 or 1.
        '''
        '''Remote-control command(s):
        '''*PSC 0 | 1
        '''
        '''</summary>
        '''<param name="Register_Value">
        '''Determines whether the content of the ENABle registers are retained or reset at power on.
        '''
        '''Valid Values: 0 | 1
        '''
        '''Default Value: 0
        '''
        '''Notes:
        '''
        '''0: The content of the status registers is retained at power on. If the status registers ESE and SRE are configured accordingly, this may cause a service request to be triggered at power on.
        '''
        '''1: The content of the status registers is reset at power on.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function PowerOnStatusClear(ByVal Register_Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.PowerOnStatusClear(Me._handle, Register_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''POWER ON STATUS CLEAR QUERY retrieves the contents of the Power-on-Status-Clear flag. The answer is either 0 or 1.
        '''
        '''Remote-control command(s):
        '''*PSC?
        '''
        '''</summary>
        '''<param name="Register_Value">
        '''Returns the contents of the Power-on-Status-Clear flag. The answer is either 0 or 1.
        '''
        '''Values:
        '''
        '''0: The content of the status registers is retained at power on. If the status registers ESE and SRE are configured accordingly, this may cause a service request to be triggered at power on.
        '''
        '''1: The content of the status registers is reset at power on.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function PowerOnStatusClearQuery(ByRef Register_Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.PowerOnStatusClearQuery(Me._handle, Register_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''RECALL calls up the instrument status which was stored under the specified number using the *SAV command or using the MMEMory:STORe:STATe command. "0" corresponds to the power-on state, unless a new instrument setting was stored under this number in the meantime using the MMEMory:STORe:STATe command. This function can also be used to call up the 3 intermediate instrument states which are stored with *SAV.
        '''
        '''Remote-control command(s):
        '''*RCL
        '''
        '''</summary>
        '''<param name="Instrument_Status">
        '''Number under which is stored instrument setting.
        '''
        '''Valid Range: 0 to 10
        '''
        '''Default Value: 0
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function Recall(ByVal Instrument_Status As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.Recall(Me._handle, Instrument_Status)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''SAVE stores the current device state under the specified number (see also *RCL). This function is used to store the 3 intermediate instrument states and to store the current instrument state internally when the instrument is switched off. This state is then restored at power on.
        '''
        '''Remote-control command(s):
        '''*SAV
        '''
        '''</summary>
        '''<param name="Instrument_Status">
        '''Number under which will be stored instrument setting.
        '''
        '''Valid Range: 0 to 10
        '''
        '''Default Value: 0
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function Save(ByVal Instrument_Status As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.Save(Me._handle, Instrument_Status)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''SERVICE REQUEST ENABLE sets the service request enable register to the specified value. Bit 6 (MSS enable bit) remains 0. This function determines the conditions under which a service request is triggered. The *SRE? query command reads out the content of the service request enable register in decimal form. Bit 6 is always 0.
        '''
        '''Remote-control command(s):
        '''*SRE
        '''
        '''</summary>
        '''<param name="Register_Value">
        '''Ssets the service request enable register to the specified value.
        '''
        '''Valid Range: 0 to 255
        '''
        '''Default Value: 0
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ServiceRequestEnable(ByVal Register_Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ServiceRequestEnable(Me._handle, Register_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''SERVICE REQUEST ENABLE reads out the content of the service request enable register in decimal form. Bit 6 is always 0.
        '''
        '''Remote-control command(s):
        '''*SRE?
        '''
        '''</summary>
        '''<param name="Register_Value">
        '''Returns the content of the service request enable register in decimal form.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function ServiceRequestEnableQuery(ByRef Register_Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ServiceRequestEnableQuery(Me._handle, Register_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''READ STATUS BYTE QUERY reads out the content of the status byte in decimal form.
        '''
        '''Remote-control command(s):
        '''*STB?
        '''
        '''</summary>
        '''<param name="Status_Byte">
        '''Returns the content of the status byte in decimal form.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function StatusByteQuery(ByRef Status_Byte As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.StatusByteQuery(Me._handle, Status_Byte)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''TRIGGER triggers all actions which are waiting for a trigger event. Specific trigger events can be triggered by means of the "TRIGger" command system (sweep and lists) or the SOURce subsystems (baseband).
        '''
        '''Remote-control command(s):
        '''*TRG
        '''
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function Trigger() As Integer
            Dim pInvokeResult As Integer = PInvoke.Trigger(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function triggers all actions waiting for a trigger event in the currently active window and waits for operation completed (OPC) before returning the status code.
        '''
        '''</summary>
        '''<param name="Timeout">
        '''Sets the timeout for the triggering routine to be finished. If the length of time required for triggering exceeds the timeout value, then the function will return with a timeout error.
        '''
        '''Valid Range: 0 ms to 600000 ms
        '''
        '''Default Value: 15000 ms
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function TriggerWaitOPC(ByVal Timeout As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.TriggerWaitOPC(Me._handle, Timeout)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the operating mode of the trigger connector.
        '''
        '''Use mode  RSSGS_TRG_CON_OP_MODE_MEASLATENCY to activate the trigger pulse for time measurments.
        '''
        '''Remote-control command(s):
        ''':CONNector:TRIGger:OMODe &lt;mode&gt;
        '''
        '''</summary>
        '''<param name="Mode">
        '''This control sets the operating mode of the trigger connector.
        '''
        '''
        '''Valid Values:
        '''
        '''RSSGS_TRG_CON_OP_MODE_IN             (0) - In       
        '''RSSGS_TRG_CON_OP_MODE_LO             (1) - Low    
        '''RSSGS_TRG_CON_OP_MODE_MEASLATENCY    (2) - Measurement Latency
        '''RSSGS_TRG_CON_OP_MODE_MEASMSGARRIVED (3) - Measurement Message Arrived
        '''RSSGS_TRG_CON_OP_MODE_HI             (4) - High
        '''RSSGS_TRG_CON_OP_MODE_FBFAULT        (5) - FB Fault
        '''RSSGS_TRG_CON_OP_MODE_SIGNALVALID    (6) - Signal Valid
        '''RSSGS_TRG_CON_OP_MODE_EXTOUT1        (7) - External Output 1
        '''RSSGS_TRG_CON_OP_MODE_EXTOUT2        (8) - External Output 2
        '''RSSGS_TRG_CON_OP_MODE_BLANK          (9) - Blank
        '''
        '''Default Value: RSSGS_TRG_CON_OP_MODE_IN (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetTrigConnnectorOpMode(ByVal Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetTrigConnnectorOpMode(Me._handle, Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function gets the operating mode of the trigger connector.
        '''
        '''
        '''Remote-control command(s):
        ''':CONNector:TRIGger:OMODe?
        '''
        '''</summary>
        '''<param name="Mode">
        '''Displays the operating mode of the trigger connector.
        '''
        '''Valid Values:
        '''RSSGS_TRG_CON_OP_MODE_IN             (0) - In       
        '''RSSGS_TRG_CON_OP_MODE_LO             (1) - Low    
        '''RSSGS_TRG_CON_OP_MODE_MEASLATENCY    (2) - Measurement Latency
        '''RSSGS_TRG_CON_OP_MODE_MEASMSGARRIVED (3) - Measurement Message Arrived
        '''RSSGS_TRG_CON_OP_MODE_HI             (4) - High
        '''RSSGS_TRG_CON_OP_MODE_FBFAULT        (5) - FB Fault
        '''RSSGS_TRG_CON_OP_MODE_SIGNALVALID    (6) - Signal Valid
        '''RSSGS_TRG_CON_OP_MODE_EXTOUT1        (7) - External Output 1
        '''RSSGS_TRG_CON_OP_MODE_EXTOUT2        (8) - External Output 2
        '''RSSGS_TRG_CON_OP_MODE_BLANK          (9) - Blank
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetTrigConnnectorOpMode(ByRef Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetTrigConnnectorOpMode(Me._handle, Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''SELF TEST QUERY triggers all self tests of the instrument and outputs an error code in decimal form (see Service Manual supplied with the instrument).
        '''
        '''Remote-control command(s):
        '''*TST?
        '''
        '''</summary>
        '''<param name="Error_Code">
        '''Returns an error code of the self tests.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SelfTestQuery(ByRef Error_Code As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SelfTestQuery(Me._handle, Error_Code)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''WAIT-to-CONTINUE does not allow subsequent commands to be processed until all previous commands have been executed and all signals are in their transient condition.
        '''
        '''Remote-control command(s):
        '''*WAI
        '''
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function WaittoContinue() As Integer
            Dim pInvokeResult As Integer = PInvoke.WaittoContinue(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function presets all parameters which are related to the signal path.
        '''
        '''Remote-control command(s):
        '''SOURce:PRESet
        '''
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function PresetSignalPath() As Integer
            Dim pInvokeResult As Integer = PInvoke.PresetSignalPath(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the names of the assemblies available in the instrument. 
        '''
        '''A complete list of all assemblies is returned (the various entries are separated by commas). The length of the list is variable and depends on the instrument equipment configuration. 
        '''
        '''
        '''Remote-control command(s):
        '''DIAGnostic:BGINfo:CATalog?
        '''
        '''</summary>
        '''<param name="Array_Size">
        '''Array size of the parameter labeled 'Module Names'.
        '''
        '''Valid Range: &gt; 0
        '''
        '''Default Value: 256
        '''
        '''</param>
        '''<param name="Module_Names">
        '''Returns complete list of all assemblies (the various entries are separated by commas). The length of the list is variable, depends on the instrument equipment configuration and is limited to the size defined by 'Array Size' parameter.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function DIAGnosticModuleNames(ByVal Array_Size As Integer, ByVal Module_Names As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.DIAGnosticModuleNames(Me._handle, Array_Size, Module_Names)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the test points available in the instrument. A detailed description of the test points can be found in Chapter 3 of the Service Manual (supplied with the instrument).  
        '''
        '''
        '''Remote-control command(s):
        '''DIAGnostic:POINt:CATalog?
        '''
        '''</summary>
        '''<param name="Array_Size">
        '''Array size of the parameter labeled 'Test Points'.
        '''
        '''Valid Range: &gt; 0
        '''
        '''Default Value: 256
        '''
        '''</param>
        '''<param name="Test_Points">
        '''Returns the test points available in the instrument (the various entries are separated by commas).
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function DIAGnosticTestPoints(ByVal Array_Size As Integer, ByVal Test_Points As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.DIAGnosticTestPoints(Me._handle, Array_Size, Test_Points)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function triggers voltage measurement at the specified test point and returns the measured voltage. A detailed description of the test points can be found in Chapter 3 of the Service Manual (supplied with the instrument). 
        '''
        '''A list of the available test points can be queried using the DIAG:POIN:CAT? command .   
        '''
        '''
        '''Remote-control command(s):
        '''DIAGnostic[:MEASure:]POINt? &lt;test point name&gt;
        '''
        '''</summary>
        '''<param name="Test_Point_Name">
        '''Test point name.
        '''
        '''Valid Values: 
        '''not checked
        '''
        '''Default Value: 
        '''not defined
        '''</param>
        '''<param name="Measured_Voltage">
        '''Returns the voltage measured at the specified test point.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function DIAGnosticTestPointVoltage(ByVal Test_Point_Name As String, ByRef Measured_Voltage As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.DIAGnosticTestPointVoltage(Me._handle, Test_Point_Name, Measured_Voltage)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''The respective hardware assembly responds directly to this function; any safety mechanisms are bypassed. 
        '''
        '''
        '''Remote-control command(s):
        '''TEST:DIRect? SCOM | RF  
        '''
        '''
        '''
        '''
        '''</summary>
        '''<param name="Bar">
        '''Selects the device.
        '''
        '''Valid Values:
        '''Not checked.
        '''
        '''Default Value: 0
        '''</param>
        '''<param name="Adress">
        '''Selects register address to read from.
        '''
        '''Valid Values:
        '''Not checked.
        '''
        '''Default Value: 0
        '''</param>
        '''<param name="Data">
        '''Returns register contents.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function DIAGnosticGetMemoryContent(ByVal Bar As Integer, ByVal Adress As Integer, ByRef Data As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.DIAGnosticGetMemoryContent(Me._handle, Bar, Adress, Data)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the contents of a register on a specific device. For service purposes only.
        '''
        '''
        '''Remote-control command(s):
        '''TEST:DIRect
        '''
        '''
        '''
        '''</summary>
        '''<param name="Bar">
        '''Identifies the device.
        '''
        '''Valid Values:
        '''Not checked.
        '''
        '''Default Value: 0
        '''</param>
        '''<param name="Adress">
        '''Selects register address.
        '''
        '''Valid Values:
        '''Not checked.
        '''
        '''Default Value: 0
        '''</param>
        '''<param name="Data">
        '''The register contents.
        '''
        '''Valid Values:
        '''Not checked.
        '''
        '''Default Value: 0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function DIAGnosticSetMemoryContent(ByVal Bar As Integer, ByVal Adress As Integer, ByVal Data As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.DIAGnosticSetMemoryContent(Me._handle, Bar, Adress, Data)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function changes the default drive. This drive is used for all subsequent MMEM commands if no path is specified with them.
        '''
        '''
        '''Remote-control command(s):
        '''MMEMory:MSIS &lt;drive_name&gt;
        '''</summary>
        '''<param name="Drive">
        '''Drive name parameter.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: "D:"
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryChangeDefaultDrive(ByVal Drive As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryChangeDefaultDrive(Me._handle, Drive)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the default drive. This drive is used for all subsequent MMEM commands if no path is specified with them.
        '''
        '''Remote-control command(s):
        '''MMEMory:MSIS?
        '''</summary>
        '''<param name="Array_Size">
        '''Defines size of array in argument Driver.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 5
        '''</param>
        '''<param name="Drive">
        '''Default Drive name.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryGetDefaultDrive(ByVal Array_Size As Integer, ByVal Drive As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryGetDefaultDrive(Me._handle, Array_Size, Drive)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function changes the default directory. This directory is used for all subsequent MMEM commands if no path is specified with them. It is also possible to change to a higher directory using two dots '..'.
        '''
        '''
        '''Remote-control command(s):
        '''MMEMory:CDIRectory &lt;directory_name&gt;
        '''</summary>
        '''<param name="Directory_Name">
        '''Directory name parameter.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: ".."
        '''
        '''Note:
        '''
        '''It is also possible to change to a higher directory using two dots '..'.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryChangeDirectory(ByVal Directory_Name As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryChangeDirectory(Me._handle, Directory_Name)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the current working directory.
        '''
        '''Remote-control command(s):
        '''MMEMory:CDIR?
        '''</summary>
        '''<param name="Array_Size">
        '''Defines size of array in argument Directory.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 1024
        '''</param>
        '''<param name="Directory">
        '''Current working directory.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryGetDirectory(ByVal Array_Size As Integer, ByVal Directory As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryGetDirectory(Me._handle, Array_Size, Directory)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function copies the first specified file to the second specified file. Instead of just a file, this function can also be used to copy a complete directory together with all its files. 
        '''
        '''If &lt;destination&gt; is not specified, &lt;source&gt; is copied to the MMEM:MSIS drive and the MMEM:CDIR directory. Files which already exist with the same name in the destination directory are overwritten without an error message.
        '''
        '''
        '''Remote-control command(s):
        '''MMEMory:COPY &lt;source&gt;[,&lt;destination&gt;]
        '''
        '''</summary>
        '''<param name="Source_Path">
        '''Source path of the file or a complete directory together with all its files.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: "D:"
        '''
        '''</param>
        '''<param name="Destination_Path">
        '''Destination path of the file or a directory. If 'Destination Path' is not specified, 'Source Path' is copied to the MMEM:MSIS drive and the MMEM:CDIR directory.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: VI_NULL
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryCopy(ByVal Source_Path As String, ByVal Destination_Path As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryCopy(Me._handle, Source_Path, Destination_Path)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function writes the block data &lt;binary block data&gt; to the file identified by &lt;file_name&gt;. The IEC/IEEE-bus terminator should be set to EOI in order to ensure correct data transfer.
        '''
        '''This function can be used to transfer stored instrument settings or waveforms directly to the instrument.
        '''
        '''
        '''Remote-control command(s):
        '''MMEMory:DATA &lt;file_name&gt;[,&lt;binary block data&gt;]
        '''
        '''</summary>
        '''<param name="File_Name">
        '''File name of the binary block data.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: "TEST1.WV"
        '''
        '''</param>
        '''<param name="Binary_Block_Length">
        '''Defines the number of bytes in the 'Binary Block Data' array.
        '''
        '''Valid Range: &gt; 0
        '''
        '''Default Value: none
        '''
        '''</param>
        '''<param name="Binary_Block_Data">
        '''Binary block data array to be writen to the file defined by 'File Name' parameter with the size limited with 'Binary Block Length' parameter.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: none
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryBlockDataWrite(ByVal File_Name As String, ByVal Binary_Block_Length As Integer, ByVal Binary_Block_Data As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryBlockDataWrite(Me._handle, File_Name, Binary_Block_Length, Binary_Block_Data)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function transfers the specified file from the R&amp;S SGS to the IEC/IEEE bus and then on to the control computer. It is important to ensure that the intermediate memory on the control computer is large enough to take the file. In this case, the setting for the IEC/IEEE-bus terminator is irrelevant.
        '''
        '''This function can be used to read stored instrument settings or waveforms directly from the instrument.
        '''
        '''
        '''Remote-control command(s):
        '''MMEMory:DATA? &lt;file_name&gt;
        '''
        '''</summary>
        '''<param name="File_Name">
        '''File name of the binary block data.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: "wave1.wv"
        '''
        '''</param>
        '''<param name="Binary_Block_Length">
        '''Length of the binary block data array.
        '''
        '''</param>
        '''<param name="Binary_Block_Data">
        '''Binary block data to be retrieved from the file defined by the 'File Name' parameter. Array size of this parameter must be large enough to store all the retrieved data.
        '''
        '''Note:
        '''
        '''To check length of the binary block data, pass VI_NULL as the value of this parameter.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryBlockDataRead(ByVal File_Name As String, ByVal Binary_Block_Length As Integer, ByVal Binary_Block_Data As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryBlockDataRead(Me._handle, File_Name, Binary_Block_Length, Binary_Block_Data)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function reads out the subdirectories and files of the specified directory. If no directory is specified, the default directory selected with the MMEM:CDIR command is read out. The directories are output in a list (the list entries are separated by commas). 
        '''
        '''
        '''Remote-control command(s):
        '''MMEMory:CATalog? &lt;path&gt;
        '''
        '''</summary>
        '''<param name="Directory_Path">
        '''Directory path parameter.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: VI_NULL
        '''
        '''Note:
        '''
        '''If no directory is specified (VI_NULL), the default directory is used.
        '''
        '''</param>
        '''<param name="Array_Size">
        '''Array size of the parameter labeled 'Catalog List'.
        '''
        '''Valid Range: &gt; 0
        '''
        '''Default Value: 256
        '''
        '''</param>
        '''<param name="Catalog_List">
        '''Reads back catalog list. Size of the list is limited by the 'Array Size' parameter.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryCatalog(ByVal Directory_Path As String, ByVal Array_Size As Integer, ByVal Catalog_List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryCatalog(Me._handle, Directory_Path, Array_Size, Catalog_List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function reads out the subdirectories of the specified directory. If no directory is specified, the default directory selected with the MMEM:CDIR command is read out. The directories are output in a list (the list entries are separated by commas). 
        '''
        '''
        '''Remote-control command(s):
        '''MMEMory:DCATalog? &lt;path&gt;
        '''
        '''</summary>
        '''<param name="Directory_Path">
        '''Directory path parameter.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: VI_NULL
        '''
        '''Note:
        '''
        '''If no directory is specified (VI_NULL), the default directory is used.
        '''
        '''</param>
        '''<param name="Array_Size">
        '''Array size of the parameter labeled 'Catalog List'.
        '''
        '''Valid Range: &gt; 0
        '''
        '''Default Value: 256
        '''
        '''</param>
        '''<param name="Catalog_List">
        '''Reads back catalog list. Size of the list is limited by the 'Array Size' parameter.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryDirectoryCatalog(ByVal Directory_Path As String, ByVal Array_Size As Integer, ByVal Catalog_List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryDirectoryCatalog(Me._handle, Directory_Path, Array_Size, Catalog_List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function deletes the specified file.
        '''
        '''
        '''Remote-control command(s):
        '''MMEMory:DELete &lt;file_name&gt;
        '''
        '''</summary>
        '''<param name="File_Name">
        '''File name parameter.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: ""
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryDelete(ByVal File_Name As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryDelete(Me._handle, File_Name)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function creates a new subdirectory in the specified directory. If no directory is specified, a subdirectory is created in the default directory. This function can also be used to create a directory tree.
        '''
        '''
        '''Remote-control command(s):
        '''MMEMory:MDIRectory &lt;directory_name&gt;
        '''
        '''</summary>
        '''<param name="Directory_Name">
        '''Directory name parameter.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: "New_Folder"
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryMakeDirectory(ByVal Directory_Name As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryMakeDirectory(Me._handle, Directory_Name)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function renames an existing file ('File Source') if no path is specified for 'File Destination'. Otherwise the file is moved to the specified path and stored under the original file name or, if specified, a new file name.
        '''
        '''
        '''Remote-control command(s):
        '''MMEMory:MOVE &lt;file_source&gt;,&lt;file_destination&gt;
        '''
        '''</summary>
        '''<param name="File_Source">
        '''Define file source.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: ""
        '''
        '''</param>
        '''<param name="File_Destination">
        '''Define file destination.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: ""
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryMove(ByVal File_Source As String, ByVal File_Destination As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryMove(Me._handle, File_Source, File_Destination)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function deletes the specified subdirectory in the specified directory. If no directory is specified, the subdirectory with the specified name is deleted in the default directory.
        '''
        '''
        '''Remote-control command(s):
        '''MMEMory:RDIRectory &lt;directory_name&gt;
        '''
        '''</summary>
        '''<param name="Directory_Name">
        '''Directory name parameter.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: ""
        '''
        '''Note:
        '''
        '''If no directory is specified, the subdirectory with the specified name is deleted in the default directory.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function MMEMoryRemoveDirectory(ByVal Directory_Name As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.MMEMoryRemoveDirectory(Me._handle, Directory_Name)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''The respective hardware assembly responds directly to this function; any safety mechanisms are bypassed. 
        '''
        '''
        '''Remote-control command(s):
        '''TEST:DIRect? SCOM | RF 
        '''
        '''</summary>
        '''<param name="Instrument_Session">
        '''This control accepts the Instrument Handle returned by the Initialize function to select the desired instrument driver session.
        '''
        '''Default Value:  None
        '''</param>
        '''<param name="Component">
        '''Selects the hardware component.
        '''
        '''Valid Values:
        '''Not checked.
        '''
        '''Default Value: 0
        '''</param>
        '''<param name="Address">
        '''Selects the address to read from.
        '''
        '''Valid Values:
        '''Not checked.
        '''
        '''Default Value: 0
        '''</param>
        '''<param name="Data">
        '''Response of the respective hardware assembly.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function TESTDirect(ByVal Component As Integer, ByVal Address As Integer, ByRef Data As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.TESTDirect(Me._handle, Component, Address, Data)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function perform a test of the internal voltages. Returns 0 on success.
        '''
        '''Remote-control command(s):
        '''TEST:VOLTage?
        '''</summary>
        '''<param name="Result">
        '''Returns result of the test. The response "0" indicates error-free testing, and the response "1" means that an error occurred during test.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function TESTVoltage(ByRef Result As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.TESTVoltage(Me._handle, Result)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function gets the result or current state of a selftest. Returns 0 on success.
        '''
        '''Remote-control command(s):
        '''TEST:ALL:RESult?
        '''</summary>
        '''<param name="Result">
        '''Returns result of the test. The response "0" indicates error-free testing, and the response "1" means that an error occurred during test.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function TESTSelftestResult(ByRef Result As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.TESTSelftestResult(Me._handle, Result)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function perform selftest.
        '''
        '''Remote-control command(s):
        '''TEST:ALL:STARt
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function TESTSelftestStart() As Integer
            Dim pInvokeResult As Integer = PInvoke.TESTSelftestStart(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function allows us to measure PCIe execution times using an arbitrary remote control channel.
        '''
        '''Remote-control command(s):
        '''TEST:SPEEd &lt;frequency&gt;,&lt;level&gt;
        '''</summary>
        '''<param name="Frequency">
        '''Sets the frequency.
        '''
        '''Valid Values:
        '''Not checked.
        '''
        '''Default Value: 0.0
        '''</param>
        '''<param name="Level">
        '''Sets the level.
        '''
        '''
        '''Valid Values:
        '''Not checked.
        '''
        '''Default Value: 0.0
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function TestSpeed(ByVal Frequency As Double, ByVal Level As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.TestSpeed(Me._handle, Frequency, Level)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the value of selected status register.
        '''
        '''Remote-control command(s):
        '''STATus:OPERation:PTRansition
        '''STATus:OPERation:NTRansition
        '''STATus:OPERation:ENABle
        '''STATus:QUEStionable:PTRansition
        '''STATus:QUEStionable:NTRansition
        '''STATus:QUEStionable:ENABle
        '''</summary>
        '''<param name="Register_Group">
        '''Selects the status register group.
        '''
        '''Valid Values:
        '''RSSGS_REGISTER_OPERATION    (0) - Operation
        '''RSSGS_REGISTER_QUESTIONABLE (1) - Questionable
        '''
        '''Default Value: RSSGS_REGISTER_OPERATION (0)
        '''
        '''</param>
        '''<param name="Register_Type">
        '''Selects the type of status register.
        '''
        '''Valid Values:
        '''RSSGS_REGISTER_ENABLE (2) - Enable
        '''RSSGS_REGISTER_NTR    (3) - Negative Transition
        '''RSSGS_REGISTER_PTR    (4) - Positive Transition
        '''
        '''Default Value: RSSGS_REGISTER_ENABLE (2)
        '''
        '''</param>
        '''<param name="Value">
        '''Sets the value to be set to selected register.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: 32767
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetRegister(ByVal Register_Group As Integer, ByVal Register_Type As Integer, ByVal Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetRegister(Me._handle, Register_Group, Register_Type, Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the value of selected status register.
        '''
        '''Remote-control command(s):
        '''STATus:OPERation:EVENt?
        '''STATus:OPERation:CONDition?
        '''STATus:OPERation:PTRansition?
        '''STATus:OPERation:NTRansition?
        '''STATus:QUEStionable:EVENt?
        '''STATus:QUEStionable:CONDition?
        '''STATus:QUEStionable:PTRansition?
        '''STATus:QUEStionable:NTRansition?
        '''</summary>
        '''<param name="Register_Group">
        '''Selects the status register group.
        '''
        '''Valid Values:
        '''RSSGS_REGISTER_OPERATION    (0) - Operation
        '''RSSGS_REGISTER_QUESTIONABLE (1) - Questionable
        '''
        '''Default Value: RSSGS_REGISTER_OPERATION (0)
        '''
        '''</param>
        '''<param name="Register_Type">
        '''Selects the type of status register.
        '''
        '''Valid Values:
        '''RSSGS_REGISTER_COND   (0) - Condition
        '''RSSGS_REGISTER_EVENT  (1) - Event
        '''RSSGS_REGISTER_ENABLE (2) - Enable
        '''RSSGS_REGISTER_NTR    (3) - Negative Transition
        '''RSSGS_REGISTER_PTR    (4) - Positive Transition
        '''
        '''Default Value: RSSGS_REGISTER_EVENT (1)
        '''</param>
        '''<param name="Value">
        '''Returns the value of selected register.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetRegister(ByVal Register_Group As Integer, ByVal Register_Type As Integer, ByRef Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetRegister(Me._handle, Register_Group, Register_Type, Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function resets the status registers. All PTRansition parts are set to FFFFh (32767), i.e. all transitions from 0 to 1 are detected. All NTRansition parts are set to 0, i.e. a transition from 1 to 0 in a CONDition bit is not detected. The ENABle parts of STATus:OPERation and STATus:QUEStionable are set to 0, i.e. all events in these registers are not passed on.
        '''
        '''
        '''Remote-control command(s):
        '''STATus:PRESet
        '''
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function STATusPRESet() As Integer
            Dim pInvokeResult As Integer = PInvoke.STATusPRESet(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries all entries in the error queue and then deletes them. Positive error numbers denote instrument-specific errors, and negative error numbers denote error messages defined by SCPI (see Chapter 9). If the error queue is empty, 0 ("No error") is returned. 
        '''
        '''
        '''Remote-control command(s):
        '''SYSTem:ERRor:ALL?
        '''
        '''</summary>
        '''<param name="Array_Size">
        '''Array size of the parameter labeled 'Error Queue'.
        '''
        '''Valid Range: &gt; 0
        '''
        '''Default Value: 256
        '''
        '''</param>
        '''<param name="Error_Queue">
        '''Returns all entries in the error queue. Buffer length is limited by the 'Array Size' parameter.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SYSTemErrorQueueAll(ByVal Array_Size As Integer, ByVal Error_Queue As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.SYSTemErrorQueueAll(Me._handle, Array_Size, Error_Queue)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries all entries in the error queue and then deletes them. Only the error numbers are returned and not the entire error text. Positive error numbers denote instrument-specific errors, and negative error numbers denote error messages defined by SCPI (see Chapter 9). If the error queue is empty, 0 ("No error") is returned. 
        '''
        '''
        '''Remote-control command(s):
        '''SYSTem:ERRor:CODE:ALL?
        '''
        '''</summary>
        '''<param name="Array_Size">
        '''Array size of the parameter labeled 'Error Queue Code'.
        '''
        '''Valid Range: &gt; 0
        '''
        '''Default Value: 256
        '''
        '''</param>
        '''<param name="Error_Queue_Code">
        '''Returns all entries in the error queue. Only the error numbers are returned and not the entire error text. Buffer length is limited by the 'Array Size' parameter.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SYSTemErrorQueueCodeAll(ByVal Array_Size As Integer, ByVal Error_Queue_Code As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.SYSTemErrorQueueCodeAll(Me._handle, Array_Size, Error_Queue_Code)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the oldest entry in the error queue and then deletes it. Only the error number is returned and not the entire error text. Positive error numbers denote instrument-specific errors, and negative error numbers denote error messages defined by SCPI (see Chapter 9). If the error queue is empty, 0 is returned. 
        '''
        '''
        '''Remote-control command(s):
        '''SYSTem:ERRor:CODE[:NEXT]?
        '''
        '''</summary>
        '''<param name="Error_Queue_Code_Next">
        '''Returns the oldest entry in the error queue. Only the error number is returned and not the entire error text.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SYSTemErrorQueueCodeNext(ByRef Error_Queue_Code_Next As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SYSTemErrorQueueCodeNext(Me._handle, Error_Queue_Code_Next)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the number of entries in the error queue. If the error queue is empty, '0' is returned.
        '''
        '''
        '''Remote-control command(s):
        '''SYSTem:ERRor:COUNt?
        '''
        '''</summary>
        '''<param name="Error_Queue_Count">
        '''Returns the number of entries in the error queue.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SYSTemErrorQueueCount(ByRef Error_Queue_Count As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SYSTemErrorQueueCount(Me._handle, Error_Queue_Count)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns a list of all errors existing at the time when the query is started. This list corresponds to the display on the info page under manual control.
        '''
        '''Remote-control command(s):
        '''SYSTem:SERRor?
        '''
        '''</summary>
        '''<param name="Array_Size">
        '''Array size of the parameter labeled 'Error Queue'.
        '''
        '''Valid Range: &gt; 0
        '''
        '''Default Value: 256
        '''
        '''</param>
        '''<param name="Error_Queue">
        '''Returns all entries in the error queue. Buffer length is limited by the 'Array Size' parameter.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SYSTemStaticErrorQueue(ByVal Array_Size As Integer, ByVal Error_Queue As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.SYSTemStaticErrorQueue(Me._handle, Array_Size, Error_Queue)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the USB resource.
        '''
        '''Remote-control command(s):
        '''SYSTem:COMMunicate:USB:RESource?
        '''</summary>
        '''<param name="Array_Size">
        '''Array size of the parameter labeled 'Error Queue'.
        '''
        '''Valid Range: &gt; 0
        '''
        '''Default Value: 256
        '''
        '''</param>
        '''<param name="USB_Resource">
        '''This control display USB resource.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SYSTemUSBResource(ByVal Array_Size As UInteger, ByVal USB_Resource As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.SYSTemUSBResource(Me._handle, Array_Size, USB_Resource)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function clears gui error history.
        '''
        '''Remote-control command(s):
        '''SYSTem:HCLear
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SYSTemClearErrorHistory() As Integer
            Dim pInvokeResult As Integer = PInvoke.SYSTemClearErrorHistory(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function restore the device state to the factory settings.
        '''
        '''Remote-control command(s):
        '''SYSTem:FPReset
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SYSTemRestoreFactorySettings() As Integer
            Dim pInvokeResult As Integer = PInvoke.SYSTemRestoreFactorySettings(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function shutdown the device.
        '''
        '''Remote-control command(s):
        '''SYSTem:SHUTdown
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SYSTemShutdown() As Integer
            Dim pInvokeResult As Integer = PInvoke.SYSTemShutdown(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function activates and deactivates the specified protection level. There are several protection levels which disable specific service functions (authorized personnel of R&amp;S Service Deparments only). These levels are identified by the suffix under PROTect.
        '''
        '''The respective functions are disabled when the protection level is activated. No password is required for activation. A password must be entered to deactivate the protection level.  The password for the first level is 123456. This protection level can be used to lock-out internal adjustments.
        '''
        '''
        '''Remote-control command(s):
        '''SYSTem:PROTect&lt;n&gt;[:STATe] ON | OFF, password
        '''
        '''</summary>
        '''<param name="Protection_Level">
        '''Specify protection level. There are several protection levels which disable specific service functions (authorized personnel of R&amp;S Service Deparments only).
        '''
        '''Valid Range: 1 to 5
        '''
        '''Default Value: 1
        '''
        '''</param>
        '''<param name="Protection">
        '''Activates and deactivates the specified protection level.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_FALSE (0)
        '''
        '''</param>
        '''<param name="Password">
        '''The password for the specified protection level.
        '''
        '''Valid Range: not checked
        '''
        '''Default Value: "123456"
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetSYSTemProtect(ByVal Protection_Level As Integer, ByVal Protection As Boolean, ByVal Password As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetSYSTemProtect(Me._handle, Protection_Level, System.Convert.ToUInt16(Protection), Password)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries state of the specified protection level. 
        '''
        '''Remote-control command(s):
        '''SYSTem:PROTect&lt;n&gt;[:STATe]?
        '''
        '''</summary>
        '''<param name="Protection_Level">
        '''Specify protection level. There are several protection levels which disable specific service functions (authorized personnel of R&amp;S Service Deparments only).
        '''
        '''Valid Range: 1 to 5
        '''
        '''Default Value: 1
        '''
        '''</param>
        '''<param name="Protection">
        '''Returns state of the specified protection level.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemProtect(ByVal Protection_Level As Integer, ByRef Protection As Boolean) As Integer
            Dim ProtectionAsUShort As UShort
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemProtect(Me._handle, Protection_Level, ProtectionAsUShort)
            Protection = System.Convert.ToBoolean(ProtectionAsUShort)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the SCPI version with which the instrument complies.
        '''
        '''
        '''Remote-control command(s):
        '''SYSTem:VERSion?
        '''
        '''</summary>
        '''<param name="SCPI_Version">
        '''Returns the SCPI version with which the instrument complies.
        '''
        '''Notes:
        '''
        '''(1) The array must contain at least 32 elements ViChar[32].
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemVersion(ByVal SCPI_Version As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemVersion(Me._handle, SCPI_Version)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns if the startup of the instrument is completed.
        '''
        '''Remote-control command(s):
        '''SYSTem:STARtup:COMPlete?
        '''</summary>
        '''<param name="Startup_Complete">
        '''This control displays the startup of the instrument is completed.
        '''
        '''Valid Values:
        '''RSSGS_SYSTEM_INCOMPLETE (0) - Startup Incomplete
        '''RSSGS_SYSTEM_COMPLETE   (1) - Startup Complete
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemStartupStatus(ByRef Startup_Complete As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemStartupStatus(Me._handle, Startup_Complete)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the Terminator mode for the IEC bus.
        '''
        '''Remote-control command(s):
        '''SYSTem:COMMunicate:GPIB:LTERminator EOI | STANdard
        '''</summary>
        '''<param name="Mode">
        '''This control sets the Terminator mode for the IEC bus.
        '''
        '''Valid Values:
        '''RSSGS_TERMINATOR_MODE_EOI  (0) - EOI
        '''RSSGS_TERMINATOR_MODE_STAN (1) - Standard
        '''
        '''Default Value:
        '''RSSGS_TERMINATOR_MODE_EOI (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetSYSTemTerminatorMode(ByVal Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetSYSTemTerminatorMode(Me._handle, Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the Terminator mode for the IEC bus.
        '''
        '''Remote-control command(s):
        '''SYSTem:COMMunicate:GPIB:LTERminator?
        '''
        '''</summary>
        '''<param name="Mode">
        '''Displays the Terminator mode for the IEC bus.
        '''
        '''Valid Values:
        '''RSSGS_TERMINATOR_MODE_EOI  (0) - EOI
        '''RSSGS_TERMINATOR_MODE_STAN (1) - Standard
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemTerminatorMode(ByRef Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemTerminatorMode(Me._handle, Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the system data sheet id catalog.
        '''
        '''Remote-control command(s):
        '''SYSTem:SPECification:IDENtification:CATalog?
        '''</summary>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="Sheet_Catalog">
        '''Displays the system data sheet id catalog.
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemDataSheetCatalog(ByVal Array_Size As Integer, ByVal Sheet_Catalog As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemDataSheetCatalog(Me._handle, Array_Size, Sheet_Catalog)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the data sheet data.
        '''
        '''Remote-control command(s):
        '''SYSTem:SPECification?
        '''</summary>
        '''<param name="ID">
        '''This control sets the ID.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''""
        '''</param>
        '''<param name="Sheet_Data">
        '''Displays the selected sheet data.
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemDataSheetData(ByVal ID As String, ByRef Sheet_Data As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemDataSheetData(Me._handle, ID, Sheet_Data)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the data sheet data.
        '''
        '''Remote-control command(s):
        '''SYSTem:SPECification:PARameter?
        '''</summary>
        '''<param name="ID">
        '''This control sets the ID.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''""
        '''</param>
        '''<param name="Parameter">
        '''This control sets the parameter.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value:
        '''0.0
        '''</param>
        '''<param name="Sheet_Data">
        '''Displays the selected sheet data.
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemDataSheetParameter(ByVal ID As String, ByVal Parameter As Double, ByRef Sheet_Data As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemDataSheetParameter(Me._handle, ID, Parameter, Sheet_Data)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the system data sheet version.
        '''
        '''Remote-control command(s):
        '''SYSTem:SPECification:VERSion?
        '''</summary>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="Version">
        '''Displays the system data sheet version.
        '''
        '''Valid Values:
        '''Not Checked
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemDataSheetVersion(ByVal Array_Size As Integer, ByVal Version As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemDataSheetVersion(Me._handle, Array_Size, Version)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns a list of hardware assembly names.
        '''
        '''Remote-control command(s):
        ''':SYSTem:HARDware:ASSembly&lt;AssemblyIndex&gt;:NAME?
        '''</summary>
        '''<param name="Assembly_Index">
        '''This control sets the assembly index.
        '''
        '''Valid Values:
        '''RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0) - Common
        '''RSSGS_VAL_ASSEMBLY_INDEX_RF      (1) - RF
        '''
        '''Default Value:
        '''RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0)
        '''</param>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="List">
        '''Displays the list of hardware assembly names.
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemHwAssemblyNames(ByVal Assembly_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemHwAssemblyNames(Me._handle, Assembly_Index, Array_Size, List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the list of system hardware part numbers. 
        '''
        '''Remote-control command(s):
        ''':SYSTem:HARDware:ASSembly&lt;AssemblyIndex&gt;:PNUMber?
        '''
        '''</summary>
        '''<param name="Assembly_Index">
        '''This control sets the assembly index.
        '''
        '''Valid Values:
        '''RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0) - Common
        '''RSSGS_VAL_ASSEMBLY_INDEX_RF      (1) - RF
        '''
        '''Default Value:
        '''RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0)
        '''</param>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="List">
        '''Displays the list of system hardware part numbers. 
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemHwPartNumbers(ByVal Assembly_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemHwPartNumbers(Me._handle, Assembly_Index, Array_Size, List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the list of system hardware revisions.
        '''
        '''Remote-control command(s):
        ''':SYSTem:HARDware:ASSembly&lt;AssemblyIndex&gt;:REVision?
        '''</summary>
        '''<param name="Assembly_Index">
        '''This control sets the assembly index.
        '''
        '''Valid Values:
        '''RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0) - Common
        '''RSSGS_VAL_ASSEMBLY_INDEX_RF      (1) - RF
        '''
        '''Default Value:
        '''RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0)
        '''</param>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="List">
        '''Displays the the list of system hardware revisions.
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemHwRevisions(ByVal Assembly_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemHwRevisions(Me._handle, Assembly_Index, Array_Size, List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the list of hardware module serial numbers.
        '''
        '''Remote-control command(s):
        ''':SYSTem:HARDware:ASSembly&lt;AssemblyIndex&gt;:SNUMber?
        '''
        '''</summary>
        '''<param name="Assembly_Index">
        '''This control sets the assembly index.
        '''
        '''Valid Values:
        '''RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0) - Common
        '''RSSGS_VAL_ASSEMBLY_INDEX_RF      (1) - RF
        '''
        '''Default Value:
        '''RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0)
        '''</param>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="List">
        '''Displays the list of hardware module serial numbers.
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemHwSerialNumbers(ByVal Assembly_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemHwSerialNumbers(Me._handle, Assembly_Index, Array_Size, List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the list of system firmware package names.
        '''
        '''Remote-control command(s):
        ''':SYSTem:SOFTware:FIRMware:PACKage?
        '''</summary>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="List">
        '''Displays the list of system firmware package names.
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemSwFirmwarePackages(ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemSwFirmwarePackages(Me._handle, Array_Size, List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the list of system firmware versions.
        '''
        '''Remote-control command(s):
        ''':SYSTem:SOFTware:FIRMware:VERSion?
        '''</summary>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="List">
        '''Displays the list of system firmware versions.
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemSwFirmwareVersions(ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemSwFirmwareVersions(Me._handle, Array_Size, List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the list of option descriptions.
        '''
        '''
        '''Remote-control command(s):
        ''':SYSTem:SOFTware:OPTion&lt;OptionIndex&gt;:DESignation?
        '''
        '''
        '''</summary>
        '''<param name="Option_Index">
        '''This control selects the option group.
        '''
        '''Valid Values:
        '''RSSGS_VAL_OPTION_INDEX_HARDWARE  (0) - Hardware
        '''RSSGS_VAL_OPTION_INDEX_SOFTWARE  (1) - Software
        '''
        '''Default Value:
        '''RSSGS_VAL_OPTION_INDEX_HARDWARE  (0)
        '''</param>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="List">
        '''Displays the list of option descriptions.
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemSwOptionDesignations(ByVal Option_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemSwOptionDesignations(Me._handle, Option_Index, Array_Size, List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the list of system firmware option names.
        '''
        '''Remote-control command(s):
        ''':SYSTem:SOFTware:OPTion&lt;OptionIndex&gt;:NAME?
        '''
        '''</summary>
        '''<param name="Option_Index">
        '''This control selects the option group.
        '''
        '''Valid Values:
        '''RSSGS_VAL_OPTION_INDEX_HARDWARE  (0) - Hardware
        '''RSSGS_VAL_OPTION_INDEX_SOFTWARE  (1) - Software
        '''
        '''Default Value:
        '''RSSGS_VAL_OPTION_INDEX_HARDWARE  (0)
        '''</param>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="List">
        '''Displays the list of system firmware option names.
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemSwOptionNames(ByVal Option_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemSwOptionNames(Me._handle, Option_Index, Array_Size, List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the list of system firmware option expiration entries.
        '''
        '''Remote-control command(s):
        ''':SYSTem:SOFTware:OPTion&lt;OptionIndex&gt;:EXP?
        '''
        '''</summary>
        '''<param name="Option_Index">
        '''This control selects the option group.
        '''
        '''Valid Values:
        '''RSSGS_VAL_OPTION_INDEX_HARDWARE  (0) - Hardware
        '''RSSGS_VAL_OPTION_INDEX_SOFTWARE  (1) - Software
        '''
        '''Default Value:
        '''RSSGS_VAL_OPTION_INDEX_HARDWARE  (0)
        '''</param>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="List">
        '''Displays the list of system firmware option expiration entries.
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemSwOptionExpirations(ByVal Option_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemSwOptionExpirations(Me._handle, Option_Index, Array_Size, List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the list of system firmware option license count entries.
        '''
        '''Remote-control command(s):
        ''':SYSTem:SOFTware:OPTion&lt;OptionIndex&gt;:LIC?
        '''
        '''</summary>
        '''<param name="Option_Index">
        '''This control selects the option group.
        '''
        '''Valid Values:
        '''RSSGS_VAL_OPTION_INDEX_HARDWARE  (0) - Hardware
        '''RSSGS_VAL_OPTION_INDEX_SOFTWARE  (1) - Software
        '''
        '''Default Value:
        '''RSSGS_VAL_OPTION_INDEX_HARDWARE  (0)
        '''</param>
        '''<param name="Array_Size">
        '''This control sets the array size.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''64
        '''</param>
        '''<param name="List">
        '''list of system firmware option license count entries
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetSYSTemSwOptionLicenses(ByVal Option_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetSYSTemSwOptionLicenses(Me._handle, Option_Index, Array_Size, List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the default unit for angles. It is valid for all commands which determine angle values. It does not influence the manual control parameter unit and the display.
        '''
        '''Remote-control command(s):
        '''UNIT:ANGle DEG | RAD
        '''</summary>
        '''<param name="Angle_Units">
        '''Sets the default unit for angles. It is valid for all commands which determine angle values. It does not influence the manual control parameter unit and the display.
        '''
        '''Valid Values:
        '''RSSGS_UNIT_ANGLE_DEG (0) - Degrees
        '''RSSGS_UNIT_ANGLE_RAD (1) - Radius
        '''
        '''Default Value: RSSGS_UNIT_ANGLE_RAD (1)
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetAngleUnits(ByVal Angle_Units As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetAngleUnits(Me._handle, Angle_Units)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the unit for angles. 
        '''
        '''Remote-control command(s):
        '''UNIT:ANGle?
        '''</summary>
        '''<param name="Angle_Units">
        '''Gets the unit for angles. 
        '''
        '''Valid Values:
        '''RSSGS_UNIT_ANGLE_DEG (0) - Degrees
        '''RSSGS_UNIT_ANGLE_RAD (1) - Radius
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetAngleUnits(ByRef Angle_Units As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetAngleUnits(Me._handle, Angle_Units)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the default unit for power. It is valid for all commands which determine power values. It does not influence the manual control parameter unit and the display.
        '''
        '''Remote-control command(s):
        '''UNIT:POWer V | DBM
        '''</summary>
        '''<param name="Power_Units">
        '''Sets the default unit for power. It is valid for all commands which determine power values. It does not influence the manual control parameter unit and the display.
        '''
        '''Valid Values:
        '''RSSGS_UNIT_POWER_V   (0) - V
        '''RSSGS_UNIT_POWER_DBM (1) - dBm
        '''
        '''Default Value: RSSGS_UNIT_POWER_DBM (1)
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetPowerUnits(ByVal Power_Units As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetPowerUnits(Me._handle, Power_Units)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the unit for power.
        '''
        '''Remote-control command(s):
        '''UNIT:POWer?
        '''</summary>
        '''<param name="Power_Units">
        '''Gets the unit for power.
        '''
        '''Valid Values:
        '''RSSGS_UNIT_POWER_V   (0) - V
        '''RSSGS_UNIT_POWER_DBM (1) - dBm
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetPowerUnits(ByRef Power_Units As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetPowerUnits(Me._handle, Power_Units)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the default unit for velocity. It is valid for all commands which determine velocity values. It does not influence the manual control parameter unit and the display.
        '''
        '''Remote-control command(s):
        '''UNIT:VELocity  
        '''</summary>
        '''<param name="Velocity_Units">
        '''Sets the default unit for velocity. It is valid for all commands which determine velocity values. It does not influence the manual control parameter unit and the display.
        '''
        '''Valid Values:
        '''RSSGS_UNIT_VELOCITY_MPS (0) - MPS
        '''RSSGS_UNIT_VELOCITY_KMH (1) - KMH
        '''RSSGS_UNIT_VELOCITY_MPH (2) - MPH
        '''
        '''Default Value: RSSGS_UNIT_VELOCITY_MPS (0)
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssmf_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetVelocityUnits(ByVal Velocity_Units As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetVelocityUnits(Me._handle, Velocity_Units)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the default unit for velocity. It is valid for all commands which determine velocity values. It does not influence the manual control parameter unit and the display.
        '''
        '''Remote-control command(s):
        '''UNIT:VELocity?
        '''</summary>
        '''<param name="Velocity_Units">
        '''Displays the default unit for velocity. 
        '''
        '''Valid Values:
        '''RSSMB_UNIT_VELOCITY_MPS (0) - MPS
        '''RSSMB_UNIT_VELOCITY_KMH (1) - KMH
        '''RSSMB_UNIT_VELOCITY_MPH (2) - MPH
        '''
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssmf_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetVelocityUnits(ByRef Velocity_Units As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetVelocityUnits(Me._handle, Velocity_Units)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the data format for IEC bus.
        '''
        '''Remote-control command(s):
        '''FORMat[:DATA] ASCii | PACKed
        '''</summary>
        '''<param name="Format">
        '''Sets the data format for IEC bus.
        '''
        '''Valid Values:
        '''RSSGS_FORMAT_DATA_ASCII (0) - ASCII
        '''RSSGS_FORMAT_DATA_PACK  (1) - Packet
        '''
        '''Default Value:
        '''RSSGS_FORMAT_DATA_ASCII (0)
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function SetFormatData(ByVal Format As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetFormatData(Me._handle, Format)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the data format for IEC bus.
        '''
        '''Remote-control command(s):
        '''FORMat[:DATA]?
        '''</summary>
        '''<param name="Format">
        '''Displays the data format for IEC bus.
        '''
        '''Valid Values:
        '''RSSGS_FORMAT_DATA_ASCII (0) - ASCII
        '''RSSGS_FORMAT_DATA_PACK  (1) - Packet
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function GetFormatData(ByRef Format As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetFormatData(Me._handle, Format)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function switches state checking of the instrument (reading of the Standard Event Register and checking it for error) status subsystem. Driver functions are using state checking which is by default enabled.
        '''
        '''Note:
        '''
        '''(1) In debug mode enable state checking.
        '''
        '''(2) For better bus throughput and instruments performance disable state checking.
        '''
        '''(3) When state checking is disabled driver does not check if correct instrument model or option is used with each of the functions. This might cause unexpected behaviour of the instrument.
        '''
        '''</summary>
        '''<param name="State_Checking">
        '''This control switches instrument state checking On or Off.
        '''
        '''Valid Range:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On (Default Value)
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This driver defines the following status codes:
        '''          
        '''Status    Description
        '''-------------------------------------------------
        '''BFFC0002  Parameter 2 (State Checking) out of range.
        '''          
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function errorCheckState(ByVal State_Checking As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.errorCheckState(Me._handle, System.Convert.ToUInt16(State_Checking))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function switches option checking of the instrument.
        '''</summary>
        '''<param name="State_Checking">
        '''This control switches instrument and option checking On or Off.
        '''
        '''Valid Range:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On (Default Value)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This driver defines the following status codes:
        '''          
        '''Status    Description
        '''-------------------------------------------------
        '''BFFC0002  Parameter 2 (State Checking) out of range.
        '''          
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function optionCheckState(ByVal State_Checking As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.optionCheckState(Me._handle, System.Convert.ToUInt16(State_Checking))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function switches range checking of the instrument.
        '''</summary>
        '''<param name="Range_Checking">
        '''This control switches instrument and range checking On or Off.
        '''
        '''Valid Range:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On (Default Value)
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This driver defines the following status codes:
        '''          
        '''Status    Description
        '''-------------------------------------------------
        '''BFFC0002  Parameter 2 (State Checking) out of range.
        '''          
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function setCheckRange(ByVal Range_Checking As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.setCheckRange(Me._handle, System.Convert.ToUInt16(Range_Checking))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function writes commands and queries to the instrument to modify parameters and query device settings.
        '''</summary>
        '''<param name="Write_Buffer">
        '''The user can use this control to send common commands and queries to the instrument. This control can also be used to write any valid command to the instrument.
        '''
        '''Default Value:  "*RST"
        '''
        '''Notes:
        '''
        '''(1) This function or query to be sent to the instrument may be a literal enclosed in double quotes i.e. "*RST" or may be contained in a variable of type string.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function writeInstrData(ByVal Write_Buffer As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.writeInstrData(Me._handle, Write_Buffer)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function reads data from the instrument's output buffer and returns it to the specified variable in memory.
        '''
        '''Notes:
        '''
        '''(1) Because the instrument may return both numeric and text data in response to queries this function returns the data in string format.
        '''
        '''(2) If valid data is not available at the instrument's output buffer when this function is called the instrument will hang up and the function will not return until it times out.  If the time-out is disabled this function will hang indefinitely and it may be necessary to reboot the computer to break out.
        '''</summary>
        '''<param name="Number_Bytes_To_Read">
        '''The number of bytes specified by this control should be greater than or equal to the number of bytes which are to be read from the instrument. If the actual number of bytes to be read is greater than the number this control specifies then multiple reads will be required to empty the instrument's output buffer.
        '''
        '''If the instrument's output buffer is not emptied the instrument may return invalid data when future reads are performed.
        '''
        '''Default Value:  50 (See NOTE 2)
        '''
        '''Notes:
        '''
        '''(1) If NO DATA is available at the instrument's output buffer when this function is called the instrument will hang up and the function will not return until it times out.  If the time-out is disabled, this function will hang indefinitely and it may be necessary to reboot the computer.
        '''
        '''(2) If the number of bytes expected is greater than 50 the value of this control may be increased. If the actual number of bytes read is larger than the declared size of the read buffer a run-time error will be generated.
        '''
        '''</param>
        '''<param name="Read_Buffer">
        '''The incoming data from the instrument is placed into this variable.
        '''
        '''Notes:
        '''
        '''(1) Because the instrument may return both numeric and text data in response to queries this function returns the data in string format.
        '''
        '''(2) This function does not overwrite any old data left in the string variable from the last time the function was called. String data in LabWindows/CVI is terminated with an ASCII null(0x0) and string manipulation functions will only recognize data before the ASCII null.
        '''
        '''(3) The declared size of the string variable must be greater than the actual number of bytes read from the instrument if it is not a run-time error will be generated.
        '''
        '''</param>
        '''<param name="NumBytes_Read">
        '''This variable contains the actual number of bytes read from the instrument. This is the value which is returned by the read function.
        '''
        '''Notes:
        '''
        '''(1) If the actual number of bytes read is less than the number of bytes specified in the Number Bytes To Read control then the output buffer has probably been emptied. If the read function fails and the number of bytes read is 0, the most probable cause for the failure is there was no data available at the instrument's output buffer.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function readInstrData(ByVal Number_Bytes_To_Read As Integer, ByVal Read_Buffer As System.Text.StringBuilder, ByRef NumBytes_Read As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.readInstrData(Me._handle, Number_Bytes_To_Read, Read_Buffer, NumBytes_Read)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''RESET resets the instrument to a defined default state. The function has the same effect as pressing the PRESET key.
        '''
        '''Remote-control command(s):
        '''*RST
        '''*CLS
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function reset() As Integer
            Dim pInvokeResult As Integer = PInvoke.reset(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''clears the device's input and output buffers
        '''
        '''Remote-control command(s):
        '''
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function Clear() As Integer
            Dim pInvokeResult As Integer = PInvoke.Clear(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function runs the instrument's self test routine and returns the test result(s).
        '''
        '''</summary>
        '''<param name="Self_Test_Result">
        '''This control contains the value returned from the instrument self test. Zero means success. For any other code, see the device's operator's manual.
        '''
        '''</param>
        '''<param name="Self_Test_Message">
        '''This control contains the string returned from the self test. See the device's operation manual for an explanation of the string's contents.
        '''
        '''Notes:
        '''
        '''(1) The array must contain at least 256 elements ViChar[256].
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This driver defines the following status codes:
        '''          
        '''Status    Description
        '''-------------------------------------------------
        '''BFFC0002  Parameter 2 (Self-Test Result) NULL pointer.
        '''          
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function self_test(ByRef Self_Test_Result As Short, ByVal Self_Test_Message As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.self_test(Me._handle, Self_Test_Result, Self_Test_Message)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function reads an error code from the instrument's error queue.
        '''
        '''</summary>
        '''<param name="Error_Code">
        '''This control returns the error code read from the instrument's error queue.
        '''
        '''</param>
        '''<param name="Error_Message">
        '''This control returns the error message string read from the instrument's error message queue.
        '''
        '''Notes:
        '''
        '''(1) The array must contain at least 256 elements ViChar[256].
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This driver defines the following status codes:
        '''          
        '''Status    Description
        '''-------------------------------------------------
        '''BFFC0002  Parameter 2 (Error Code) NULL pointer.
        '''BFFC0003  Parameter 3 (Error Message) NULL pointer.
        '''          
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function error_query(ByRef Error_Code As Integer, ByVal Error_Message As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.error_query(Me._handle, Error_Code, Error_Message)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the revision numbers of the instrument driver and instrument firmware, and tells the user with which  instrument firmware this revision of the driver is compatible.
        '''
        '''</summary>
        '''<param name="Instrument_Driver_Revision">
        '''This control returns the Instrument Driver Software Revision.
        '''
        '''Notes:
        '''
        '''(1) The array must contain at least 256 elements ViChar[256].
        '''
        '''</param>
        '''<param name="Firmware_Revision">
        '''This control returns the Instrument Firmware Revision.
        '''
        '''Notes:
        '''
        '''(1) The array must contain at least 256 elements ViChar[256].
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function revision_query(ByVal Instrument_Driver_Revision As System.Text.StringBuilder, ByVal Firmware_Revision As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.revision_query(Me._handle, Instrument_Driver_Revision, Firmware_Revision)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function suspends the program for the selected number of second.
        '''</summary>
        '''<param name="Seconds">
        '''This control sets the number of seconds.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 0.0 s
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Function delay(ByVal Seconds As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.delay(Me._handle, Seconds)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function enumerates PCIe devices.
        '''
        '''Remote-control command(s):
        '''
        '''</summary>
        '''<param name="Vendor_ID">
        '''Vendor ID.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 0
        '''</param>
        '''<param name="Device_ID">
        '''Device ID.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 0
        '''</param>
        '''<param name="Serial_Numbers">
        '''Array of returned serial numbers. Allocated by caller.
        '''</param>
        '''<param name="Array_Size">
        '''Size of 'Serial Numbers' array. On return: number of found devices.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''          
        '''Numeric Range (in Hex)   Status Code Types    
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF     VISA     Warnings
        '''3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        '''          
        '''BFFF0000 to BFFFFFFF     VISA     Errors
        '''BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        '''
        '''</returns>
        Public Shared Function enumerate_pcie_devices(ByVal Vendor_ID As Integer, ByVal Device_ID As Integer, ByVal Serial_Numbers() As Integer, ByRef Array_Size As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.enumerate_pcie_devices(Vendor_ID, Device_ID, Serial_Numbers, Array_Size)
            PInvoke.TestForError(New System.Runtime.InteropServices.HandleRef(Nothing, System.IntPtr.Zero), pInvokeResult)
            Return pInvokeResult
        End Function
        
        Public Overloads Sub Dispose() Implements System.IDisposable.Dispose
            Me.Dispose(true)
            System.GC.SuppressFinalize(Me)
        End Sub
        
        Private Overloads Sub Dispose(ByVal disposing As Boolean)
            If (Me._disposed = false) Then
                PInvoke.close(Me._handle)
                Me._handle = New System.Runtime.InteropServices.HandleRef(Nothing, System.IntPtr.Zero)
            End If
            Me._disposed = true
        End Sub
        
        Protected Overrides Sub Finalize()
            Me.Dispose(false)
        End Sub
        
        Private Class PInvoke
            
<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_init", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function init (ByVal Resource_Name As String, ByVal ID_Query As UShort, ByVal Reset_Device As UShort, ByRef Instrument_Handle As System.IntPtr) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetFrequencyAndLevel", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetFrequencyAndLevel (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Frequency As Double, ByVal Level As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_UseFastSettings", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function UseFastSettings (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Fast_Enabled As UShort, ByVal Asynchronous_Enabled As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_FastSync", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FastSync (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetRFState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetRFState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal State As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetRFState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetRFState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef State As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetRFNumberofPaths", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetRFNumberofPaths (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Paths As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetRFAttenuatorMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetRFAttenuatorMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Attenuator_Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetRFAttenuatorMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetRFAttenuatorMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Attenuator_Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetOperationMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetOperationMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Operation_Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetOperationMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetOperationMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Operation_Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetBasebandPaths", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetBasebandPaths (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Baseband_Paths As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ConfigureFrequencyLocalOscillator", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureFrequencyLocalOscillator (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Source As Integer, ByVal Output As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetFrequency", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetFrequency (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Frequency As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetFrequency", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetFrequency (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Frequency As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetFrequencyDeltaPhase", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetFrequencyDeltaPhase (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Delta_Phase As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetFrequencyDeltaPhase", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetFrequencyDeltaPhase (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Delta_Phase As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetFrequencyDeltaPhaseAsCurrent", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetFrequencyDeltaPhaseAsCurrent (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetFrequencyLocalOscillatorSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetFrequencyLocalOscillatorSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Source As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetFrequencyLocalOscillatorSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetFrequencyLocalOscillatorSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Source As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetFrequencyLocalOscillatorOutput", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetFrequencyLocalOscillatorOutput (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Output As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetFrequencyLocalOscillatorOutput", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetFrequencyLocalOscillatorOutput (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Output As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ConfigureReferenceOscillator", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureReferenceOscillator (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Source As Integer, ByVal Reference_Frequency As Integer, ByVal External_Reference_Frequency As Integer, ByVal Local_Oscillator_Source As Integer, ByVal Local_Oscillator_Output As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetROSCSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetROSCSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Source As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetROSCSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetROSCSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Source As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetROSCReferenceOutputFrequency", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetROSCReferenceOutputFrequency (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Reference_Frequency As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetROSCReferenceOutputFrequency", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetROSCReferenceOutputFrequency (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Reference_Frequency As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetROSCExternalReferenceFrequency", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetROSCExternalReferenceFrequency (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal External_Reference_Frequency As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetROSCExternalReferenceFrequency", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetROSCExternalReferenceFrequency (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef External_Reference_Frequency As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetROSCExternalSyncBandwidth", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetROSCExternalSyncBandwidth (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Synchronization_Bandwidth As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetROSCExternalSyncBandwidth", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetROSCExternalSyncBandwidth (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Synchronization_Bandwidth As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetROSCCalibrationData", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetROSCCalibrationData (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Data As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetROSCCalibrationData", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetROSCCalibrationData (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Data As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetROSCAdjustmentActive", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetROSCAdjustmentActive (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Adjustment_Active As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetROSCAdjustmentActive", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetROSCAdjustmentActive (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Adjustment_Active As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetROSCAdjustmentValue", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetROSCAdjustmentValue (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Adjustment_Value As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetROSCAdjustmentValue", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetROSCAdjustmentValue (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Adjustment_Value As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetLevel", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetLevel (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Level As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ConfigureLevelSettings", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureLevelSettings (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Mode As Integer, ByVal Setting_Characteristic As Integer, ByVal Limit As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetLevelMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetLevelMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetLevelMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetLevelMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetLevelSettingCharacteristic", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetLevelSettingCharacteristic (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Setting_Characteristic As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetLevelSettingCharacteristic", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetLevelSettingCharacteristic (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Setting_Characteristic As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetLevel", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetLevel (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Level As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetLevelLimit", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetLevelLimit (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Limit As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetLevelLimit", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetLevelLimit (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Limit As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetLevelPowerOnState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetLevelPowerOnState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Power_On_State As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetLevelPowerOnState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetLevelPowerOnState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Power_On_State As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetLevelALCState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetLevelALCState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal State As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetLevelALCState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetLevelALCState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef State As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ReadjustLevelALC", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ReadjustLevelALC (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetAttenuatorModeAfterOn", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetAttenuatorModeAfterOn (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetAttenuatorModeAfterOn", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetAttenuatorModeAfterOn (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetAttenuatorSwitchOverOffset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetAttenuatorSwitchOverOffset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Offset As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetAttenuatorSwitchOverOffset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetAttenuatorSwitchOverOffset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Offset As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetAttenuatorLowerRange", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetAttenuatorLowerRange (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Attenuator_Lower_Range As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetAttenuatorUpperRange", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetAttenuatorUpperRange (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Attenuator_Upper_Range As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ConfigureIQ", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureIQ (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal IQ_Modulator_State As UShort, ByVal IQ_Wideband As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ConfigureIQImpairments", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureIQImpairments (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal State As UShort, ByVal I_Offset As Double, ByVal Q_Offset As Double, ByVal Gain_Imbalance As Double, ByVal Quadrature_Offset As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetIQModulatorState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetIQModulatorState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal IQ_Modulator_State As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetIQModulatorState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetIQModulatorState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef IQ_Modulator_State As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetIQImpairmentsState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetIQImpairmentsState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal State As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetIQImpairmentsState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetIQImpairmentsState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef State As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetIQImpairmentsIOffset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetIQImpairmentsIOffset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal I_Offset As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetIQImpairmentsIOffset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetIQImpairmentsIOffset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef I_Offset As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetIQImpairmentsQOffset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetIQImpairmentsQOffset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Q_Offset As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetIQImpairmentsQOffset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetIQImpairmentsQOffset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Q_Offset As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetIQImpairmentsGainImbalance", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetIQImpairmentsGainImbalance (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Gain_Imbalance As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetIQImpairmentsGainImbalance", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetIQImpairmentsGainImbalance (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Gain_Imbalance As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetIQImpairmentsQuadratureOffset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetIQImpairmentsQuadratureOffset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Quadrature_Offset As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetIQImpairmentsQuadratureOffset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetIQImpairmentsQuadratureOffset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Quadrature_Offset As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetIQWideband", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetIQWideband (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal IQ_Wideband As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetIQWideband", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetIQWideband (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef IQ_Wideband As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ConfigureExtension", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureExtension (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal State As UShort, ByVal Hardware_Channel As Integer, ByVal Instrument_Name As String, ByVal Serial_Number As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetExtensionState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetExtensionState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal State As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetExtensionState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetExtensionState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef State As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetExtensionHardwareChannel", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetExtensionHardwareChannel (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Hardware_Channel As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetExtensionHardwareChannel", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetExtensionHardwareChannel (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Hardware_Channel As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetExtensionInstrumentName", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetExtensionInstrumentName (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Instrument_Name As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetExtensionInstrumentName", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetExtensionInstrumentName (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Instrument_Name As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetExtensionSerialNumber", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetExtensionSerialNumber (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Serial_Number As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetExtensionSerialNumber", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetExtensionSerialNumber (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Serial_Number As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetExtensionRemoteState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetExtensionRemoteState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Remote_State As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetExtensionBusyState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetExtensionBusyState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Busy_State As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_LockInstrument", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function LockInstrument (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Lock_ID As Integer, ByRef Result As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_UnlockInstrument", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function UnlockInstrument (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Lock_ID As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_CALibrationAll", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function CALibrationAll (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Timeout As Integer, ByRef Result As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_CALibrationLevel", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function CALibrationLevel (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Timeout As Integer, ByRef Result As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_CALibrationSynthesis", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function CALibrationSynthesis (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Timeout As Integer, ByRef Result As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_CALibrationIQModulator", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function CALibrationIQModulator (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Timeout As Integer, ByRef Result As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_CALibrationIQModulatorForCurrentFrequency", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function CALibrationIQModulatorForCurrentFrequency (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Timeout As Integer, ByRef Result As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetNetworkSystemSettings", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetNetworkSystemSettings (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetNetworkMACAddress", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetNetworkMACAddress (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal MAC_Address As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ConfigureNetworkIP", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureNetworkIP (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Address_Mode As Integer, ByVal IP_Address As String, ByVal Subnet_Mask As String, ByVal Default_Gateway As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetNetworkResource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetNetworkResource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As UInteger, ByVal Resource As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetNetworkConfigurationState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetNetworkConfigurationState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Configuration As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetNetworkCommonHostname", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetNetworkCommonHostname (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Hostname As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetNetworkCommonHostname", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetNetworkCommonHostname (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Hostname As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetNetworkIPAddressMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetNetworkIPAddressMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Address_Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetNetworkIPAddressMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetNetworkIPAddressMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Address_Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetNetworkIPAddress", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetNetworkIPAddress (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal IP_Address As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetNetworkIPAddress", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetNetworkIPAddress (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal IP_Address As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetNetworkIPSubnetMask", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetNetworkIPSubnetMask (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Subnet_Mask As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetNetworkIPSubnetMask", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetNetworkIPSubnetMask (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Subnet_Mask As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetNetworkIPDefaultGateway", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetNetworkIPDefaultGateway (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Default_Gateway As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetNetworkIPDefaultGateway", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetNetworkIPDefaultGateway (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Default_Gateway As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_AcceptNetworkIPSettings", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function AcceptNetworkIPSettings (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetRemoteOperationMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetRemoteOperationMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Operation_Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetRemoteOperationMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetRemoteOperationMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Operation_Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ClearStatus", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ClearStatus (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_EventStatusEnable", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function EventStatusEnable (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Register_Value As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_EventStatusQuery", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function EventStatusQuery (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Register_Value As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_IdentificationQuery", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function IdentificationQuery (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Instrument_Identification As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_IndividualStatusQuery", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function IndividualStatusQuery (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef IST_Flag As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_OperationComplete", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function OperationComplete (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_OperationCompleteQuery", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function OperationCompleteQuery (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef OPC_State As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_OptionIdentificationQuery", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function OptionIdentificationQuery (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Option_Identification As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ParallelPollRegisterEnable", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ParallelPollRegisterEnable (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Register_Value As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ParallelPollRegisterQuery", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ParallelPollRegisterQuery (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Register_Value As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_PowerOnStatusClear", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function PowerOnStatusClear (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Register_Value As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_PowerOnStatusClearQuery", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function PowerOnStatusClearQuery (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Register_Value As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_Recall", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function Recall (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Instrument_Status As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_Save", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function Save (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Instrument_Status As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ServiceRequestEnable", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ServiceRequestEnable (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Register_Value As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_ServiceRequestEnableQuery", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ServiceRequestEnableQuery (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Register_Value As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_StatusByteQuery", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function StatusByteQuery (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Status_Byte As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_Trigger", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function Trigger (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_TriggerWaitOPC", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function TriggerWaitOPC (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Timeout As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetTrigConnnectorOpMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetTrigConnnectorOpMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetTrigConnnectorOpMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetTrigConnnectorOpMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SelfTestQuery", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SelfTestQuery (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Error_Code As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_WaittoContinue", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function WaittoContinue (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_PresetSignalPath", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function PresetSignalPath (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_DIAGnosticModuleNames", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function DIAGnosticModuleNames (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Module_Names As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_DIAGnosticTestPoints", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function DIAGnosticTestPoints (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Test_Points As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_DIAGnosticTestPointVoltage", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function DIAGnosticTestPointVoltage (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Test_Point_Name As String, ByRef Measured_Voltage As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_DIAGnosticGetMemoryContent", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function DIAGnosticGetMemoryContent (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Bar As Integer, ByVal Adress As Integer, ByRef Data As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_DIAGnosticSetMemoryContent", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function DIAGnosticSetMemoryContent (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Bar As Integer, ByVal Adress As Integer, ByVal Data As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryChangeDefaultDrive", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryChangeDefaultDrive (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Drive As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryGetDefaultDrive", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryGetDefaultDrive (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Drive As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryChangeDirectory", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryChangeDirectory (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Directory_Name As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryGetDirectory", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryGetDirectory (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Directory As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryCopy", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryCopy (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Source_Path As String, ByVal Destination_Path As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryBlockDataWrite", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryBlockDataWrite (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal File_Name As String, ByVal Binary_Block_Length As Integer, ByVal Binary_Block_Data As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryBlockDataRead", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryBlockDataRead (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal File_Name As String, ByVal Binary_Block_Length As Integer, ByVal Binary_Block_Data As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryCatalog", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryCatalog (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Directory_Path As String, ByVal Array_Size As Integer, ByVal Catalog_List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryDirectoryCatalog", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryDirectoryCatalog (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Directory_Path As String, ByVal Array_Size As Integer, ByVal Catalog_List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryDelete", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryDelete (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal File_Name As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryMakeDirectory", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryMakeDirectory (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Directory_Name As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryMove", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryMove (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal File_Source As String, ByVal File_Destination As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_MMEMoryRemoveDirectory", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MMEMoryRemoveDirectory (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Directory_Name As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_TESTDirect", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function TESTDirect (ByVal Instrument_Session As System.Runtime.InteropServices.HandleRef, ByVal Component As Integer, ByVal Address As Integer, ByRef Data As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_TESTVoltage", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function TESTVoltage (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Result As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_TESTSelftestResult", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function TESTSelftestResult (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Result As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_TESTSelftestStart", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function TESTSelftestStart (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_TestSpeed", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function TestSpeed (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Frequency As Double, ByVal Level As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetRegister", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetRegister (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Register_Group As Integer, ByVal Register_Type As Integer, ByVal Value As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetRegister", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetRegister (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Register_Group As Integer, ByVal Register_Type As Integer, ByRef Value As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_STATusPRESet", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function STATusPRESet (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SYSTemErrorQueueAll", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SYSTemErrorQueueAll (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Error_Queue As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SYSTemErrorQueueCodeAll", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SYSTemErrorQueueCodeAll (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Error_Queue_Code As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SYSTemErrorQueueCodeNext", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SYSTemErrorQueueCodeNext (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Error_Queue_Code_Next As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SYSTemErrorQueueCount", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SYSTemErrorQueueCount (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Error_Queue_Count As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SYSTemStaticErrorQueue", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SYSTemStaticErrorQueue (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Error_Queue As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SYSTemUSBResource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SYSTemUSBResource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As UInteger, ByVal USB_Resource As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SYSTemClearErrorHistory", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SYSTemClearErrorHistory (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SYSTemRestoreFactorySettings", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SYSTemRestoreFactorySettings (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SYSTemShutdown", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SYSTemShutdown (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetSYSTemProtect", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetSYSTemProtect (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Protection_Level As Integer, ByVal Protection As UShort, ByVal Password As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemProtect", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemProtect (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Protection_Level As Integer, ByRef Protection As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemVersion", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemVersion (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal SCPI_Version As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemStartupStatus", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemStartupStatus (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Startup_Complete As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetSYSTemTerminatorMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetSYSTemTerminatorMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemTerminatorMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemTerminatorMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Mode As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemDataSheetCatalog", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemDataSheetCatalog (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Sheet_Catalog As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemDataSheetData", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemDataSheetData (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal ID As String, ByRef Sheet_Data As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemDataSheetParameter", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemDataSheetParameter (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal ID As String, ByVal Parameter As Double, ByRef Sheet_Data As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemDataSheetVersion", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemDataSheetVersion (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal Version As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemHwAssemblyNames", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemHwAssemblyNames (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Assembly_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemHwPartNumbers", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemHwPartNumbers (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Assembly_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemHwRevisions", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemHwRevisions (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Assembly_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemHwSerialNumbers", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemHwSerialNumbers (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Assembly_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemSwFirmwarePackages", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemSwFirmwarePackages (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemSwFirmwareVersions", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemSwFirmwareVersions (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemSwOptionDesignations", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemSwOptionDesignations (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Option_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemSwOptionNames", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemSwOptionNames (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Option_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemSwOptionExpirations", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemSwOptionExpirations (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Option_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetSYSTemSwOptionLicenses", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetSYSTemSwOptionLicenses (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Option_Index As Integer, ByVal Array_Size As Integer, ByVal List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetAngleUnits", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetAngleUnits (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Angle_Units As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetAngleUnits", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetAngleUnits (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Angle_Units As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetPowerUnits", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetPowerUnits (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Power_Units As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetPowerUnits", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetPowerUnits (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Power_Units As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetVelocityUnits", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetVelocityUnits (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Velocity_Units As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetVelocityUnits", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetVelocityUnits (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Velocity_Units As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_SetFormatData", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetFormatData (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Format As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_GetFormatData", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetFormatData (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Format As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_errorCheckState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function errorCheckState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal State_Checking As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_optionCheckState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function optionCheckState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal State_Checking As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_setCheckRange", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function setCheckRange (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Range_Checking As UShort) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_writeInstrData", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function writeInstrData (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Write_Buffer As String) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_readInstrData", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function readInstrData (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Number_Bytes_To_Read As Integer, ByVal Read_Buffer As System.Text.StringBuilder, ByRef NumBytes_Read As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_reset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function reset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_Clear", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function Clear (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_self_test", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function self_test (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Self_Test_Result As Short, ByVal Self_Test_Message As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_error_query", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function error_query (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Error_Code As Integer, ByVal Error_Message As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_revision_query", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function revision_query (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Instrument_Driver_Revision As System.Text.StringBuilder, ByVal Firmware_Revision As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_delay", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function delay (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Seconds As Double) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_enumerate_pcie_devices", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function enumerate_pcie_devices (ByVal Vendor_ID As Integer, ByVal Device_ID As Integer, <[In], Out> Serial_Numbers As Integer(), ByRef Array_Size As Integer) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_close", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function close (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rssgs_32.dll", EntryPoint:="rssgs_error_message", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function error_message (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Status_Code As Integer, ByVal Message As System.Text.StringBuilder) As Integer
End Function

            
            Public Shared Function TestForError(ByVal handle As System.Runtime.InteropServices.HandleRef, ByVal status As Integer) As Integer
                If (status < 0) Then
                    PInvoke.ThrowError(handle, status)
                End If
                Return status
            End Function
            
            Public Shared Function ThrowError(ByVal handle As System.Runtime.InteropServices.HandleRef, ByVal code As Integer) As Integer
                Dim msg As System.Text.StringBuilder = New System.Text.StringBuilder(256)
                PInvoke.error_message(handle, code, msg)
                Throw New System.Runtime.InteropServices.ExternalException(msg.ToString, code)
            End Function
        End Class
    End Class
    
    Public Class rssgsConstants
        
        Public Const RfAttModeAuto As Integer = 0
        
        Public Const RfAttModeFix As Integer = 1
        
        Public Const OperationModeNormal As Integer = 0
        
        Public Const OperationModeBby As Integer = 1
        
        Public Const SourceInt As Integer = 0
        
        Public Const SourceExt As Integer = 1
        
        Public Const LoOutputRef As Integer = 0
        
        Public Const LoOutputLo As Integer = 1
        
        Public Const LoOutputOff As Integer = 2
        
        Public Const RoscRefFreqOf10m As Integer = 0
        
        Public Const RoscRefFreqOf100m As Integer = 1
        
        Public Const RoscRefFreqOf1000m As Integer = 2
        
        Public Const RoscRefFreqOff As Integer = 3
        
        Public Const RoscExtRefFreqEf10m As Integer = 0
        
        Public Const RoscExtRefFreqEf100m As Integer = 1
        
        Public Const RoscExtRefFreqEf1000m As Integer = 2
        
        Public Const RoscExtSyncBwidthWide As Integer = 0
        
        Public Const RoscExtSyncBwidthNarrow As Integer = 1
        
        Public Const LevelModeAuto As Integer = 0
        
        Public Const LevelModeLno As Integer = 1
        
        Public Const LevelModeLdis As Integer = 2
        
        Public Const LevelSettCharactAuto As Integer = 0
        
        Public Const LevelSettCharactUnin As Integer = 1
        
        Public Const LevelSettCharactMon As Integer = 2
        
        Public Const LevelSettCharactCwsw As Integer = 3
        
        Public Const LevelPowOnOff As Integer = 0
        
        Public Const LevelPowOnUnch As Integer = 1
        
        Public Const LevelAlcStateOnt As Integer = 0
        
        Public Const LevelAlcStateOn As Integer = 1
        
        Public Const LevelAlcStateOfft As Integer = 2
        
        Public Const LevelAttOnFix As Integer = 0
        
        Public Const LevelAttOnMax As Integer = 1
        
        Public Const SguHwChannLan As Integer = 0
        
        Public Const SguHwChannUsb As Integer = 1
        
        Public Const SguHwChannPcie As Integer = 2
        
        Public Const SguHwChannSock As Integer = 3
        
        Public Const IpAddressModeAuto As Integer = 0
        
        Public Const IpAddressModeStat As Integer = 1
        
        Public Const RemoteOperModeExt As Integer = 0
        
        Public Const RemoteOperModeStd As Integer = 1
        
        Public Const TrgConOpModeIn As Integer = 0
        
        Public Const TrgConOpModeLo As Integer = 1
        
        Public Const TrgConOpModeMeaslatency As Integer = 2
        
        Public Const TrgConOpModeMeasmsgarrived As Integer = 3
        
        Public Const TrgConOpModeHi As Integer = 4
        
        Public Const TrgConOpModeFbfault As Integer = 5
        
        Public Const TrgConOpModeSignalvalid As Integer = 6
        
        Public Const TrgConOpModeExtout1 As Integer = 7
        
        Public Const TrgConOpModeExtout2 As Integer = 8
        
        Public Const TrgConOpModeBlank As Integer = 9
        
        Public Const RegisterOperation As Integer = 0
        
        Public Const RegisterQuestionable As Integer = 1
        
        Public Const RegisterEnable As Integer = 2
        
        Public Const RegisterNtr As Integer = 3
        
        Public Const RegisterPtr As Integer = 4
        
        Public Const RegisterCond As Integer = 0
        
        Public Const RegisterEvent As Integer = 1
        
        Public Const TerminatorModeEoi As Integer = 0
        
        Public Const TerminatorModeStan As Integer = 1
        
        Public Const AssemblyIndexCommon As Integer = 0
        
        Public Const AssemblyIndexRf As Integer = 1
        
        Public Const OptionIndexHardware As Integer = 0
        
        Public Const OptionIndexSoftware As Integer = 1
        
        Public Const UnitAngleDeg As Integer = 0
        
        Public Const UnitAngleRad As Integer = 1
        
        Public Const UnitPowerV As Integer = 0
        
        Public Const UnitPowerDbm As Integer = 1
        
        Public Const UnitVelocityMps As Integer = 0
        
        Public Const UnitVelocityKmh As Integer = 1
        
        Public Const UnitVelocityMph As Integer = 2
        
        Public Const FormatDataAscii As Integer = 0
        
        Public Const FormatDataPack As Integer = 1
    End Class
End Namespace
